from ._12 import *

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class UpdateConferencingSettingsResponse(DataClassJsonMixin):
    uri: Optional[str] = None
    """ Canonical URI of a conferencing """
    
    allow_join_before_host: Optional[bool] = None
    """ Determines if host user allows conference participants to join before the host """
    
    host_code: Optional[str] = None
    """ Access code for a host user """
    
    mode: Optional[str] = None
    """ Internal parameter specifying conferencing engine """
    
    participant_code: Optional[str] = None
    """ Access code for any participant """
    
    phone_number: Optional[str] = None
    """
    Primary conference phone number for user's home country returned in
    [E.164](https://www.itu.int/rec/T-REC-E.164-201011-I) format
    """
    
    tap_to_join_uri: Optional[str] = None
    """ Short URL leading to the service web page Tap to Join for audio conference bridge """
    
    phone_numbers: Optional[List[UpdateConferencingSettingsResponsePhoneNumbersItem]] = None
    """
    List of multiple dial-in phone numbers to connect to audio conference service, relevant for
    user's brand. Each number is given with the country and location information, in order to let
    the user choose the less expensive way to connect to a conference. The first number in the list
    is the primary conference number, that is default and domestic
    """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorAccount(DataClassJsonMixin):
    """ Account information """
    
    id: Optional[str] = None
    """ Internal identifier of an account """
    
    uri: Optional[str] = None
    """ Canonical URI of an account """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorContactBusinessAddress(DataClassJsonMixin):
    """ Business address of extension user company """
    
    country: Optional[str] = None
    """ Country name of an extension user company """
    
    state: Optional[str] = None
    """ State/province name of an extension user company. Mandatory for the USA, UK and Canada """
    
    city: Optional[str] = None
    """ City name of an extension user company """
    
    street: Optional[str] = None
    """ Street address of an extension user company """
    
    zip: Optional[str] = None
    """ Zip code of an extension user company """
    

class ReadAccountInfoResponseOperatorContactPronouncedNameType(Enum):
    """
    Voice name type. 'Default' - default extension name; first name and last name specified in user
    profile; 'TextToSpeech' - custom text; user name spelled the way it sounds and specified by
    user; 'Recorded' - custom audio, user name recorded in user's own voice (supported only for
    extension retrieval)
    
    Generated by Python OpenAPI Parser
    """
    
    Default = 'Default'
    TextToSpeech = 'TextToSpeech'
    Recorded = 'Recorded'

class ReadAccountInfoResponseOperatorContactPronouncedNamePromptContentType(Enum):
    """ Content media type """
    
    AudioMpeg = 'audio/mpeg'
    AudioWav = 'audio/wav'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorContactPronouncedNamePrompt(DataClassJsonMixin):
    id: Optional[str] = None
    content_uri: Optional[str] = None
    """ Link to a prompt resource """
    
    content_type: Optional[ReadAccountInfoResponseOperatorContactPronouncedNamePromptContentType] = None
    """ Content media type """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorContactPronouncedName(DataClassJsonMixin):
    type: Optional[ReadAccountInfoResponseOperatorContactPronouncedNameType] = None
    """
    Voice name type. 'Default' - default extension name; first name and last name specified in user
    profile; 'TextToSpeech' - custom text; user name spelled the way it sounds and specified by
    user; 'Recorded' - custom audio, user name recorded in user's own voice (supported only for
    extension retrieval)
    """
    
    text: Optional[str] = None
    """ Custom text """
    
    prompt: Optional[ReadAccountInfoResponseOperatorContactPronouncedNamePrompt] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorContact(DataClassJsonMixin):
    """ Contact detailed information """
    
    first_name: Optional[str] = None
    """ For User extension type only. Extension user first name """
    
    last_name: Optional[str] = None
    """ For User extension type only. Extension user last name """
    
    company: Optional[str] = None
    """ Extension user company name """
    
    job_title: Optional[str] = None
    email: Optional[str] = None
    """ Email of extension user """
    
    business_phone: Optional[str] = None
    """
    Extension user contact phone number in [E.164](https://www.itu.int/rec/T-REC-E.164-201011-I)
    (with '+' sign) format
    """
    
    mobile_phone: Optional[str] = None
    """
    Extension user mobile (**non** Toll Free) phone number in
    [E.164](https://www.itu.int/rec/T-REC-E.164-201011-I) (with '+' sign) format
    """
    
    business_address: Optional[ReadAccountInfoResponseOperatorContactBusinessAddress] = None
    """ Business address of extension user company """
    
    email_as_login_name: Optional[bool] = 'False'
    """
    If 'True' then contact email is enabled as login name for this user. Please note that email
    should be unique in this case.
    """
    
    pronounced_name: Optional[ReadAccountInfoResponseOperatorContactPronouncedName] = None
    department: Optional[str] = None
    """ Extension user department, if any """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorCustomFieldsItem(DataClassJsonMixin):
    id: Optional[str] = None
    """ Internal identifier of a custom field """
    
    value: Optional[str] = None
    """ Custom field value """
    
    display_name: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorDepartmentsItem(DataClassJsonMixin):
    id: Optional[str] = None
    """ Internal identifier of a department extension """
    
    uri: Optional[str] = None
    """ Canonical URI of a department extension """
    
    extension_number: Optional[str] = None
    """ Number of a department extension """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorPermissionsAdmin(DataClassJsonMixin):
    """ Admin permission """
    
    enabled: Optional[bool] = None
    """ Specifies if a permission is enabled or not """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorPermissionsInternationalCalling(DataClassJsonMixin):
    """ International Calling permission """
    
    enabled: Optional[bool] = None
    """ Specifies if a permission is enabled or not """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorPermissions(DataClassJsonMixin):
    """
    Extension permissions, corresponding to the Service Web permissions 'Admin' and
    'InternationalCalling'
    
    Generated by Python OpenAPI Parser
    """
    
    admin: Optional[ReadAccountInfoResponseOperatorPermissionsAdmin] = None
    """ Admin permission """
    
    international_calling: Optional[ReadAccountInfoResponseOperatorPermissionsInternationalCalling] = None
    """ International Calling permission """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorProfileImageScalesItem(DataClassJsonMixin):
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorProfileImage(DataClassJsonMixin):
    """
    Information on profile image
    
    Required Properties:
     - uri
    
    Generated by Python OpenAPI Parser
    """
    
    uri: str
    """ Link to a profile image. If an image is not uploaded for an extension, only uri is returned """
    
    etag: Optional[str] = None
    """ Identifier of an image """
    
    last_modified: Optional[datetime] = field(metadata=config(encoder=datetime.isoformat, decoder=datetime_decoder(datetime)), default=None)
    """
    The datetime when an image was last updated in ISO 8601 format, for example
    2016-03-10T18:07:52.534Z
    """
    
    content_type: Optional[str] = None
    """ The type of an image """
    
    scales: Optional[List[ReadAccountInfoResponseOperatorProfileImageScalesItem]] = None
    """ List of URIs to profile images in different dimensions """
    

class ReadAccountInfoResponseOperatorReferencesItemType(Enum):
    """ Type of external identifier """
    
    PartnerId = 'PartnerId'
    CustomerDirectoryId = 'CustomerDirectoryId'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorReferencesItem(DataClassJsonMixin):
    ref: Optional[str] = None
    """ Non-RC identifier of an extension """
    
    type: Optional[ReadAccountInfoResponseOperatorReferencesItemType] = None
    """ Type of external identifier """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorRolesItem(DataClassJsonMixin):
    uri: Optional[str] = None
    id: Optional[str] = None
    """ Internal identifier of a role """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorRegionalSettingsHomeCountry(DataClassJsonMixin):
    """ Extension country information """
    
    id: Optional[str] = None
    """ Internal identifier of a home country """
    
    uri: Optional[str] = None
    """ Canonical URI of a home country """
    
    name: Optional[str] = None
    """ Official name of a home country """
    
    iso_code: Optional[str] = None
    """ ISO code of a country """
    
    calling_code: Optional[str] = None
    """ Calling code of a country """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorRegionalSettingsTimezone(DataClassJsonMixin):
    """ Extension timezone information """
    
    id: Optional[str] = None
    """ Internal identifier of a timezone """
    
    uri: Optional[str] = None
    """ Canonical URI of a timezone """
    
    name: Optional[str] = None
    """ Short name of a timezone """
    
    description: Optional[str] = None
    """ Meaningful description of the timezone """
    
    bias: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorRegionalSettingsLanguage(DataClassJsonMixin):
    """ User interface language data """
    
    id: Optional[str] = None
    """ Internal identifier of a language """
    
    uri: Optional[str] = None
    """ Canonical URI of a language """
    
    greeting: Optional[bool] = None
    """ Indicates whether a language is available as greeting language """
    
    formatting_locale: Optional[bool] = None
    """ Indicates whether a language is available as formatting locale """
    
    locale_code: Optional[str] = None
    """ Localization code of a language """
    
    iso_code: Optional[str] = None
    """
    Country code according to the ISO standard, see [ISO
    3166](https://www.iso.org/iso-3166-country-codes.html)
    """
    
    name: Optional[str] = None
    """ Official name of a language """
    
    ui: Optional[bool] = None
    """ Indicates whether a language is available as UI language """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorRegionalSettingsGreetingLanguage(DataClassJsonMixin):
    """ Information on language used for telephony greetings """
    
    id: Optional[str] = None
    """ Internal identifier of a greeting language """
    
    locale_code: Optional[str] = None
    """ Localization code of a greeting language """
    
    name: Optional[str] = None
    """ Official name of a greeting language """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorRegionalSettingsFormattingLocale(DataClassJsonMixin):
    """ Formatting language preferences for numbers, dates and currencies """
    
    id: Optional[str] = None
    """ Internal identifier of a formatting language """
    
    locale_code: Optional[str] = None
    """ Localization code of a formatting language """
    
    name: Optional[str] = None

class ReadAccountInfoResponseOperatorRegionalSettingsTimeFormat(Enum):
    """ Time format setting. The default value is '12h' = ['12h', '24h'] """
    
    OBJECT_12h = '12h'
    OBJECT_24h = '24h'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorRegionalSettings(DataClassJsonMixin):
    """ Extension region data (timezone, home country, language) """
    
    home_country: Optional[ReadAccountInfoResponseOperatorRegionalSettingsHomeCountry] = None
    """ Extension country information """
    
    timezone: Optional[ReadAccountInfoResponseOperatorRegionalSettingsTimezone] = None
    """ Extension timezone information """
    
    language: Optional[ReadAccountInfoResponseOperatorRegionalSettingsLanguage] = None
    """ User interface language data """
    
    greeting_language: Optional[ReadAccountInfoResponseOperatorRegionalSettingsGreetingLanguage] = None
    """ Information on language used for telephony greetings """
    
    formatting_locale: Optional[ReadAccountInfoResponseOperatorRegionalSettingsFormattingLocale] = None
    """ Formatting language preferences for numbers, dates and currencies """
    
    time_format: Optional[ReadAccountInfoResponseOperatorRegionalSettingsTimeFormat] = None
    """ Time format setting. The default value is '12h' = ['12h', '24h'] """
    

class ReadAccountInfoResponseOperatorServiceFeaturesItemFeatureName(Enum):
    """ Feature name """
    
    AccountFederation = 'AccountFederation'
    Archiver = 'Archiver'
    AutomaticCallRecordingMute = 'AutomaticCallRecordingMute'
    AutomaticInboundCallRecording = 'AutomaticInboundCallRecording'
    AutomaticOutboundCallRecording = 'AutomaticOutboundCallRecording'
    BlockedMessageForwarding = 'BlockedMessageForwarding'
    Calendar = 'Calendar'
    CallerIdControl = 'CallerIdControl'
    CallForwarding = 'CallForwarding'
    CallPark = 'CallPark'
    CallParkLocations = 'CallParkLocations'
    CallSupervision = 'CallSupervision'
    CallSwitch = 'CallSwitch'
    CallQualitySurvey = 'CallQualitySurvey'
    Conferencing = 'Conferencing'
    ConferencingNumber = 'ConferencingNumber'
    ConfigureDelegates = 'ConfigureDelegates'
    DeveloperPortal = 'DeveloperPortal'
    DND = 'DND'
    DynamicConference = 'DynamicConference'
    EmergencyAddressAutoUpdate = 'EmergencyAddressAutoUpdate'
    EmergencyCalling = 'EmergencyCalling'
    EncryptionAtRest = 'EncryptionAtRest'
    ExternalDirectoryIntegration = 'ExternalDirectoryIntegration'
    Fax = 'Fax'
    FaxReceiving = 'FaxReceiving'
    FreeSoftPhoneLines = 'FreeSoftPhoneLines'
    HDVoice = 'HDVoice'
    HipaaCompliance = 'HipaaCompliance'
    Intercom = 'Intercom'
    InternationalCalling = 'InternationalCalling'
    InternationalSMS = 'InternationalSMS'
    LinkedSoftphoneLines = 'LinkedSoftphoneLines'
    MMS = 'MMS'
    MobileVoipEmergencyCalling = 'MobileVoipEmergencyCalling'
    OnDemandCallRecording = 'OnDemandCallRecording'
    Pager = 'Pager'
    PagerReceiving = 'PagerReceiving'
    Paging = 'Paging'
    PasswordAuth = 'PasswordAuth'
    PromoMessage = 'PromoMessage'
    Reports = 'Reports'
    Presence = 'Presence'
    RCTeams = 'RCTeams'
    RingOut = 'RingOut'
    SalesForce = 'SalesForce'
    SharedLines = 'SharedLines'
    SingleExtensionUI = 'SingleExtensionUI'
    SiteCodes = 'SiteCodes'
    SMS = 'SMS'
    SMSReceiving = 'SMSReceiving'
    SoftPhoneUpdate = 'SoftPhoneUpdate'
    TelephonySessions = 'TelephonySessions'
    UserManagement = 'UserManagement'
    VideoConferencing = 'VideoConferencing'
    VoipCalling = 'VoipCalling'
    VoipCallingOnMobile = 'VoipCallingOnMobile'
    Voicemail = 'Voicemail'
    VoicemailToText = 'VoicemailToText'
    WebPhone = 'WebPhone'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorServiceFeaturesItem(DataClassJsonMixin):
    enabled: Optional[bool] = None
    """ Feature status; shows feature availability for an extension """
    
    feature_name: Optional[ReadAccountInfoResponseOperatorServiceFeaturesItemFeatureName] = None
    """ Feature name """
    
    reason: Optional[str] = None
    """
    Reason for limitation of a particular service feature. Returned only if the enabled parameter
    value is 'False', see Service Feature Limitations and Reasons. When retrieving service features
    for an extension, the reasons for the limitations, if any, are returned in response
    """
    

class ReadAccountInfoResponseOperatorSetupWizardState(Enum):
    """ Specifies extension configuration wizard state (web service setup). """
    
    NotStarted = 'NotStarted'
    Incomplete = 'Incomplete'
    Completed = 'Completed'

class ReadAccountInfoResponseOperatorStatus(Enum):
    """
    Extension current state. If 'Unassigned' is specified, then extensions without
    ‘extensionNumber’ are returned. If not specified, then all extensions are returned
    
    Generated by Python OpenAPI Parser
    """
    
    Enabled = 'Enabled'
    Disabled = 'Disabled'
    Frozen = 'Frozen'
    NotActivated = 'NotActivated'
    Unassigned = 'Unassigned'

class ReadAccountInfoResponseOperatorStatusInfoReason(Enum):
    """ Type of suspension """
    
    Voluntarily = 'Voluntarily'
    Involuntarily = 'Involuntarily'
    SuspendedVoluntarily = 'SuspendedVoluntarily'
    SuspendedVoluntarily2 = 'SuspendedVoluntarily2'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorStatusInfo(DataClassJsonMixin):
    """ Status information (reason, comment). Returned for 'Disabled' status only """
    
    comment: Optional[str] = None
    """ A free-form user comment, describing the status change reason """
    
    reason: Optional[ReadAccountInfoResponseOperatorStatusInfoReason] = None
    """ Type of suspension """
    

class ReadAccountInfoResponseOperatorType(Enum):
    """ Extension type """
    
    User = 'User'
    FaxUser = 'FaxUser'
    VirtualUser = 'VirtualUser'
    DigitalUser = 'DigitalUser'
    Department = 'Department'
    Announcement = 'Announcement'
    Voicemail = 'Voicemail'
    SharedLinesGroup = 'SharedLinesGroup'
    PagingOnly = 'PagingOnly'
    IvrMenu = 'IvrMenu'
    ApplicationExtension = 'ApplicationExtension'
    ParkLocation = 'ParkLocation'
    Bot = 'Bot'
    Room = 'Room'
    Limited = 'Limited'
    Site = 'Site'
    ProxyAdmin = 'ProxyAdmin'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorCallQueueInfo(DataClassJsonMixin):
    """ For Department extension type only. Call queue settings """
    
    sla_goal: Optional[int] = None
    """
    Target percentage of calls that must be answered by agents within the service level time
    threshold
    """
    
    sla_threshold_seconds: Optional[int] = None
    """ Period of time in seconds that is considered to be an acceptable service level """
    
    include_abandoned_calls: Optional[bool] = None
    """
    If 'True' abandoned calls (hanged up prior to being served) are included into service level
    calculation
    """
    
    abandoned_threshold_seconds: Optional[int] = None
    """
    Period of time in seconds specifying abandoned calls duration - calls that are shorter will not
    be included into the calculation of service level.; zero value means that abandoned calls of
    any duration will be included into calculation
    """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperatorSite(DataClassJsonMixin):
    """
    Site data. If multi-site feature is turned on for the account, then internal identifier of a
    site must be specified. To assign the wireless point to the main site (company) set site ID to
    `main-site`
    
    Generated by Python OpenAPI Parser
    """
    
    id: Optional[str] = None
    """ Internal identifier of a site """
    
    uri: Optional[str] = None
    """ Link to a site resource """
    
    name: Optional[str] = None
    """ Name of a site """
    
    code: Optional[str] = None
    """ Site code value. Returned only if specified """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseOperator(DataClassJsonMixin):
    """
    Operator's extension information. This extension will receive all calls and messages intended
    for the operator
    
    Generated by Python OpenAPI Parser
    """
    
    id: Optional[int] = None
    """ Internal identifier of an extension """
    
    uri: Optional[str] = None
    """ Canonical URI of an extension """
    
    account: Optional[ReadAccountInfoResponseOperatorAccount] = None
    """ Account information """
    
    contact: Optional[ReadAccountInfoResponseOperatorContact] = None
    """ Contact detailed information """
    
    custom_fields: Optional[List[ReadAccountInfoResponseOperatorCustomFieldsItem]] = None
    departments: Optional[List[ReadAccountInfoResponseOperatorDepartmentsItem]] = None
    """
    Information on department extension(s), to which the requested extension belongs. Returned only
    for user extensions, members of department, requested by single extensionId
    """
    
    extension_number: Optional[str] = None
    """ Number of department extension """
    
    extension_numbers: Optional[List[str]] = None
    name: Optional[str] = None
    """
    Extension name. For user extension types the value is a combination of the specified first name
    and last name
    """
    
    partner_id: Optional[str] = None
    """
    For Partner Applications Internal identifier of an extension created by partner. The
    RingCentral supports the mapping of accounts and stores the corresponding account ID/extension
    ID for each partner ID of a client application. In request URIs partner IDs are accepted
    instead of regular RingCentral native IDs as path parameters using pid = XXX clause. Though in
    response URIs contain the corresponding account IDs and extension IDs. In all request and
    response bodies these values are reflected via partnerId attributes of account and extension
    """
    
    permissions: Optional[ReadAccountInfoResponseOperatorPermissions] = None
    """
    Extension permissions, corresponding to the Service Web permissions 'Admin' and
    'InternationalCalling'
    """
    
    profile_image: Optional[ReadAccountInfoResponseOperatorProfileImage] = None
    """ Information on profile image """
    
    references: Optional[List[ReadAccountInfoResponseOperatorReferencesItem]] = None
    """ List of non-RC internal identifiers assigned to an extension """
    
    roles: Optional[List[ReadAccountInfoResponseOperatorRolesItem]] = None
    regional_settings: Optional[ReadAccountInfoResponseOperatorRegionalSettings] = None
    """ Extension region data (timezone, home country, language) """
    
    service_features: Optional[List[ReadAccountInfoResponseOperatorServiceFeaturesItem]] = None
    """
    Extension service features returned in response only when the logged-in user requests his/her
    own extension info, see also Extension Service Features
    """
    
    setup_wizard_state: Optional[ReadAccountInfoResponseOperatorSetupWizardState] = 'NotStarted'
    """ Specifies extension configuration wizard state (web service setup). """
    
    status: Optional[ReadAccountInfoResponseOperatorStatus] = None
    """
    Extension current state. If 'Unassigned' is specified, then extensions without
    ‘extensionNumber’ are returned. If not specified, then all extensions are returned
    """
    
    status_info: Optional[ReadAccountInfoResponseOperatorStatusInfo] = None
    """ Status information (reason, comment). Returned for 'Disabled' status only """
    
    type: Optional[ReadAccountInfoResponseOperatorType] = None
    """ Extension type """
    
    call_queue_info: Optional[ReadAccountInfoResponseOperatorCallQueueInfo] = None
    """ For Department extension type only. Call queue settings """
    
    hidden: Optional[bool] = None
    """ Hides extension from showing in company directory. Supported for extensions of User type only """
    
    site: Optional[ReadAccountInfoResponseOperatorSite] = None
    """
    Site data. If multi-site feature is turned on for the account, then internal identifier of a
    site must be specified. To assign the wireless point to the main site (company) set site ID to
    `main-site`
    """
    

class ReadAccountInfoResponseServiceInfoBillingPlanDurationUnit(Enum):
    """ Duration period """
    
    Month = 'Month'
    Day = 'Day'

class ReadAccountInfoResponseServiceInfoBillingPlanType(Enum):
    """ Billing plan type """
    
    Initial = 'Initial'
    Regular = 'Regular'
    Suspended = 'Suspended'
    Trial = 'Trial'
    TrialNoCC = 'TrialNoCC'
    Free = 'Free'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseServiceInfoBillingPlan(DataClassJsonMixin):
    """ Information on account billing plan """
    
    id: Optional[str] = None
    """ Internal identifier of a billing plan """
    
    name: Optional[str] = None
    """ Billing plan name """
    
    duration_unit: Optional[ReadAccountInfoResponseServiceInfoBillingPlanDurationUnit] = None
    """ Duration period """
    
    duration: Optional[int] = None
    """ Number of duration units """
    
    type: Optional[ReadAccountInfoResponseServiceInfoBillingPlanType] = None
    """ Billing plan type """
    
    included_phone_lines: Optional[int] = None
    """ Included digital lines count """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseServiceInfoBrandHomeCountry(DataClassJsonMixin):
    """ Home country information """
    
    id: Optional[str] = None
    """ Internal identifier of a home country """
    
    uri: Optional[str] = None
    """ Canonical URI of a home country """
    
    name: Optional[str] = None
    """ Official name of a home country """
    
    iso_code: Optional[str] = None
    """ ISO code of a country """
    
    calling_code: Optional[str] = None
    """ Calling code of a country """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseServiceInfoBrand(DataClassJsonMixin):
    """ Information on account brand """
    
    id: Optional[str] = None
    """ Internal identifier of a brand """
    
    name: Optional[str] = None
    """ Brand name, for example RingCentral UK , ClearFax """
    
    home_country: Optional[ReadAccountInfoResponseServiceInfoBrandHomeCountry] = None
    """ Home country information """
    

class ReadAccountInfoResponseServiceInfoServicePlanFreemiumProductType(Enum):
    Freyja = 'Freyja'
    Phoenix = 'Phoenix'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseServiceInfoServicePlan(DataClassJsonMixin):
    """ Information on account service plan """
    
    id: Optional[str] = None
    """ Internal identifier of a service plan """
    
    name: Optional[str] = None
    """ Name of a service plan """
    
    edition: Optional[str] = None
    """ Edition of a service plan """
    
    freemium_product_type: Optional[ReadAccountInfoResponseServiceInfoServicePlanFreemiumProductType] = None

class ReadAccountInfoResponseServiceInfoTargetServicePlanFreemiumProductType(Enum):
    Freyja = 'Freyja'
    Phoenix = 'Phoenix'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseServiceInfoTargetServicePlan(DataClassJsonMixin):
    """ Information on account target service plan """
    
    id: Optional[str] = None
    """ Internal identifier of a target service plan """
    
    name: Optional[str] = None
    """ Name of a target service plan """
    
    edition: Optional[str] = None
    """ Edition of a service plan """
    
    freemium_product_type: Optional[ReadAccountInfoResponseServiceInfoTargetServicePlanFreemiumProductType] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseServiceInfoContractedCountry(DataClassJsonMixin):
    """ Information on the contracted country of account """
    
    id: Optional[str] = None
    """ Identifier of a contracted country """
    
    uri: Optional[str] = None
    """ Canonical URI of a contracted country """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseServiceInfo(DataClassJsonMixin):
    """ Account service information, including brand, service plan and billing plan """
    
    uri: Optional[str] = None
    """ Canonical URI of a service info resource """
    
    billing_plan: Optional[ReadAccountInfoResponseServiceInfoBillingPlan] = None
    """ Information on account billing plan """
    
    brand: Optional[ReadAccountInfoResponseServiceInfoBrand] = None
    """ Information on account brand """
    
    service_plan: Optional[ReadAccountInfoResponseServiceInfoServicePlan] = None
    """ Information on account service plan """
    
    target_service_plan: Optional[ReadAccountInfoResponseServiceInfoTargetServicePlan] = None
    """ Information on account target service plan """
    
    contracted_country: Optional[ReadAccountInfoResponseServiceInfoContractedCountry] = None
    """ Information on the contracted country of account """
    

class ReadAccountInfoResponseSetupWizardState(Enum):
    """ Specifies account configuration wizard state (web service setup) """
    
    NotStarted = 'NotStarted'
    Incomplete = 'Incomplete'
    Completed = 'Completed'

class ReadAccountInfoResponseSignupInfoSignupStateItem(Enum):
    AccountCreated = 'AccountCreated'
    BillingEntered = 'BillingEntered'
    CreditCardApproved = 'CreditCardApproved'
    AccountConfirmed = 'AccountConfirmed'
    PhoneVerificationRequired = 'PhoneVerificationRequired'
    PhoneVerificationPassed = 'PhoneVerificationPassed'

class ReadAccountInfoResponseSignupInfoVerificationReason(Enum):
    CC_Failed = 'CC_Failed'
    Phone_Suspicious = 'Phone_Suspicious'
    CC_Phone_Not_Match = 'CC_Phone_Not_Match'
    AVS_Not_Available = 'AVS_Not_Available'
    MaxMind = 'MaxMind'
    CC_Blacklisted = 'CC_Blacklisted'
    Email_Blacklisted = 'Email_Blacklisted'
    Phone_Blacklisted = 'Phone_Blacklisted'
    Cookie_Blacklisted = 'Cookie_Blacklisted'
    Device_Blacklisted = 'Device_Blacklisted'
    IP_Blacklisted = 'IP_Blacklisted'
    Agent_Instance_Blacklisted = 'Agent_Instance_Blacklisted'
    Charge_Limit = 'Charge_Limit'
    Other_Country = 'Other_Country'
    Unknown = 'Unknown'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseSignupInfo(DataClassJsonMixin):
    """ Account sign up data """
    
    tos_accepted: Optional[bool] = False
    signup_state: Optional[List[ReadAccountInfoResponseSignupInfoSignupStateItem]] = None
    verification_reason: Optional[ReadAccountInfoResponseSignupInfoVerificationReason] = None
    marketing_accepted: Optional[bool] = None
    """ Updates 'Send Marketing Information' flag on web interface """
    

class ReadAccountInfoResponseStatus(Enum):
    """ Status of the current account """
    
    Initial = 'Initial'
    Confirmed = 'Confirmed'
    Unconfirmed = 'Unconfirmed'
    Disabled = 'Disabled'

class ReadAccountInfoResponseStatusInfoReason(Enum):
    """ Type of suspension """
    
    SuspendedVoluntarily = 'SuspendedVoluntarily'
    SuspendedInvoluntarily = 'SuspendedInvoluntarily'
    UserResumed = 'UserResumed'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseStatusInfo(DataClassJsonMixin):
    """ Status information (reason, comment, lifetime). Returned for 'Disabled' status only """
    
    comment: Optional[str] = None
    """ A free-form user comment, describing the status change reason """
    
    reason: Optional[ReadAccountInfoResponseStatusInfoReason] = None
    """ Type of suspension """
    
    till: Optional[str] = None
    """ Date until which the account will get deleted. The default value is 30 days since current date """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseRegionalSettingsHomeCountry(DataClassJsonMixin):
    """ Extension country information """
    
    id: Optional[str] = None
    """ Internal identifier of a home country """
    
    uri: Optional[str] = None
    """ Canonical URI of a home country """
    
    name: Optional[str] = None
    """ Official name of a home country """
    
    iso_code: Optional[str] = None
    """ ISO code of a country """
    
    calling_code: Optional[str] = None
    """ Calling code of a country """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseRegionalSettingsTimezone(DataClassJsonMixin):
    """ Extension timezone information """
    
    id: Optional[str] = None
    """ Internal identifier of a timezone """
    
    uri: Optional[str] = None
    """ Canonical URI of a timezone """
    
    name: Optional[str] = None
    """ Short name of a timezone """
    
    description: Optional[str] = None
    """ Meaningful description of the timezone """
    
    bias: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseRegionalSettingsLanguage(DataClassJsonMixin):
    """ User interface language data """
    
    id: Optional[str] = None
    """ Internal identifier of a language """
    
    uri: Optional[str] = None
    """ Canonical URI of a language """
    
    greeting: Optional[bool] = None
    """ Indicates whether a language is available as greeting language """
    
    formatting_locale: Optional[bool] = None
    """ Indicates whether a language is available as formatting locale """
    
    locale_code: Optional[str] = None
    """ Localization code of a language """
    
    iso_code: Optional[str] = None
    """
    Country code according to the ISO standard, see [ISO
    3166](https://www.iso.org/iso-3166-country-codes.html)
    """
    
    name: Optional[str] = None
    """ Official name of a language """
    
    ui: Optional[bool] = None
    """ Indicates whether a language is available as UI language """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseRegionalSettingsGreetingLanguage(DataClassJsonMixin):
    """ Information on language used for telephony greetings """
    
    id: Optional[str] = None
    """ Internal identifier of a greeting language """
    
    locale_code: Optional[str] = None
    """ Localization code of a greeting language """
    
    name: Optional[str] = None
    """ Official name of a greeting language """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseRegionalSettingsFormattingLocale(DataClassJsonMixin):
    """ Formatting language preferences for numbers, dates and currencies """
    
    id: Optional[str] = None
    """ Internal identifier of a formatting language """
    
    locale_code: Optional[str] = None
    """ Localization code of a formatting language """
    
    name: Optional[str] = None

class ReadAccountInfoResponseRegionalSettingsTimeFormat(Enum):
    """ Time format setting. The default value is '12h' = ['12h', '24h'] """
    
    OBJECT_12h = '12h'
    OBJECT_24h = '24h'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseRegionalSettingsCurrency(DataClassJsonMixin):
    """ Currency information """
    
    id: Optional[str] = None
    """ Internal identifier of a currency """
    
    code: Optional[str] = None
    """ Official code of a currency """
    
    name: Optional[str] = None
    """ Official name of a currency """
    
    symbol: Optional[str] = None
    """ Graphic symbol of a currency """
    
    minor_symbol: Optional[str] = None
    """ Minor graphic symbol of a currency """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseRegionalSettings(DataClassJsonMixin):
    """ Account level region data (web service Auto-Receptionist settings) """
    
    home_country: Optional[ReadAccountInfoResponseRegionalSettingsHomeCountry] = None
    """ Extension country information """
    
    timezone: Optional[ReadAccountInfoResponseRegionalSettingsTimezone] = None
    """ Extension timezone information """
    
    language: Optional[ReadAccountInfoResponseRegionalSettingsLanguage] = None
    """ User interface language data """
    
    greeting_language: Optional[ReadAccountInfoResponseRegionalSettingsGreetingLanguage] = None
    """ Information on language used for telephony greetings """
    
    formatting_locale: Optional[ReadAccountInfoResponseRegionalSettingsFormattingLocale] = None
    """ Formatting language preferences for numbers, dates and currencies """
    
    time_format: Optional[ReadAccountInfoResponseRegionalSettingsTimeFormat] = None
    """ Time format setting. The default value is '12h' = ['12h', '24h'] """
    
    currency: Optional[ReadAccountInfoResponseRegionalSettingsCurrency] = None
    """ Currency information """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponseLimits(DataClassJsonMixin):
    """ Limits which are effective for the account """
    
    free_soft_phone_lines_per_extension: Optional[int] = None
    """ Max number of free softphone phone lines per user extension """
    
    meeting_size: Optional[int] = None
    """ Max number of participants in RingCentral meeting hosted by this account's user """
    
    cloud_recording_storage: Optional[int] = None
    """ Meetings recording cloud storage limitaion in Gb """
    
    max_monitored_extensions_per_user: Optional[int] = None
    """ Max number of extensions which can be included in the list of users monitored for Presence """
    
    max_extension_number_length: Optional[int] = 5
    """
    Max length of extension numbers of an account; the supported value is up to 8 symbols, depends
    on account type
    """
    
    site_code_length: Optional[int] = None
    """ Length of a site code """
    
    short_extension_number_length: Optional[int] = None
    """ Length of a short extension number """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountInfoResponse(DataClassJsonMixin):
    id: Optional[int] = None
    """ Internal identifier of an account """
    
    uri: Optional[str] = None
    """ Canonical URI of an account """
    
    bsid: Optional[str] = None
    """ Internal identifier of an account in the billing system """
    
    main_number: Optional[str] = None
    """ Main phone number of the current account """
    
    operator: Optional[ReadAccountInfoResponseOperator] = None
    """
    Operator's extension information. This extension will receive all calls and messages intended
    for the operator
    """
    
    partner_id: Optional[str] = None
    """ Additional account identifier, created by partner application and applied on client side """
    
    service_info: Optional[ReadAccountInfoResponseServiceInfo] = None
    """ Account service information, including brand, service plan and billing plan """
    
    setup_wizard_state: Optional[ReadAccountInfoResponseSetupWizardState] = 'NotStarted'
    """ Specifies account configuration wizard state (web service setup) """
    
    signup_info: Optional[ReadAccountInfoResponseSignupInfo] = None
    """ Account sign up data """
    
    status: Optional[ReadAccountInfoResponseStatus] = None
    """ Status of the current account """
    
    status_info: Optional[ReadAccountInfoResponseStatusInfo] = None
    """ Status information (reason, comment, lifetime). Returned for 'Disabled' status only """
    
    regional_settings: Optional[ReadAccountInfoResponseRegionalSettings] = None
    """ Account level region data (web service Auto-Receptionist settings) """
    
    federated: Optional[bool] = None
    """ Specifies whether an account is included into any federation of accounts or not """
    
    outbound_call_prefix: Optional[int] = None
    """
    If outbound call prefix is not specified, or set to null (0), then the parameter is not
    returned; the supported value range is 2-9
    """
    
    cfid: Optional[str] = None
    """
    Customer facing identifier. Returned for accounts with the turned off PBX features. Equals to
    main company number in [E.164](https://www.itu.int/rec/T-REC-E.164-201011-I) (without '+'
    sign)format
    """
    
    limits: Optional[ReadAccountInfoResponseLimits] = None
    """ Limits which are effective for the account """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountBusinessAddressResponseBusinessAddress(DataClassJsonMixin):
    country: Optional[str] = None
    """ Country name of an extension user company """
    
    state: Optional[str] = None
    """ State/province name of an extension user company. Mandatory for the USA, UK and Canada """
    
    city: Optional[str] = None
    """ City name of an extension user company """
    
    street: Optional[str] = None
    """ Street address of an extension user company """
    
    zip: Optional[str] = None
    """ Zip code of an extension user company """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountBusinessAddressResponse(DataClassJsonMixin):
    uri: Optional[str] = None
    business_address: Optional[ReadAccountBusinessAddressResponseBusinessAddress] = None
    company: Optional[str] = None
    email: Optional[str] = None
    main_site_name: Optional[str] = None
    """ Custom site name """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class UpdateAccountBusinessAddressRequestBusinessAddress(DataClassJsonMixin):
    """ Company business address """
    
    country: Optional[str] = None
    """ Name of a country """
    
    state: Optional[str] = None
    """ Name of a state/province """
    
    city: Optional[str] = None
    """ Name of a city """
    
    street: Optional[str] = None
    """ Street address """
    
    zip: Optional[str] = None
    """ Zip code """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class UpdateAccountBusinessAddressRequest(DataClassJsonMixin):
    company: Optional[str] = None
    """ Company business name """
    
    email: Optional[str] = None
    """ Company business email address """
    
    business_address: Optional[UpdateAccountBusinessAddressRequestBusinessAddress] = None
    """ Company business address """
    
    main_site_name: Optional[str] = None
    """ Custom site name """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class UpdateAccountBusinessAddressResponseBusinessAddress(DataClassJsonMixin):
    country: Optional[str] = None
    """ Country name of an extension user company """
    
    state: Optional[str] = None
    """ State/province name of an extension user company. Mandatory for the USA, UK and Canada """
    
    city: Optional[str] = None
    """ City name of an extension user company """
    
    street: Optional[str] = None
    """ Street address of an extension user company """
    
    zip: Optional[str] = None
    """ Zip code of an extension user company """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class UpdateAccountBusinessAddressResponse(DataClassJsonMixin):
    uri: Optional[str] = None
    business_address: Optional[UpdateAccountBusinessAddressResponseBusinessAddress] = None
    company: Optional[str] = None
    email: Optional[str] = None
    main_site_name: Optional[str] = None
    """ Custom site name """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountServiceInfoResponseBrandHomeCountry(DataClassJsonMixin):
    """ Home country information """
    
    id: Optional[str] = None
    """ Internal identifier of a home country """
    
    uri: Optional[str] = None
    """ Canonical URI of a home country """
    
    name: Optional[str] = None
    """ Official name of a home country """
    
    iso_code: Optional[str] = None
    """ ISO code of a country """
    
    calling_code: Optional[str] = None
    """ Calling code of a country """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountServiceInfoResponseBrand(DataClassJsonMixin):
    """ Information on account brand """
    
    id: Optional[str] = None
    """ Internal identifier of a brand """
    
    name: Optional[str] = None
    """ Brand name, for example RingCentral UK , ClearFax """
    
    home_country: Optional[ReadAccountServiceInfoResponseBrandHomeCountry] = None
    """ Home country information """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountServiceInfoResponseContractedCountry(DataClassJsonMixin):
    """ Information on the contracted country of account """
    
    id: Optional[str] = None
    """ Identifier of a contracted country """
    
    uri: Optional[str] = None
    """ Canonical URI of a contracted country """
    

class ReadAccountServiceInfoResponseServicePlanFreemiumProductType(Enum):
    Freyja = 'Freyja'
    Phoenix = 'Phoenix'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountServiceInfoResponseServicePlan(DataClassJsonMixin):
    """ Information on account service plan """
    
    id: Optional[str] = None
    """ Internal identifier of a service plan """
    
    name: Optional[str] = None
    """ Name of a service plan """
    
    edition: Optional[str] = None
    """ Edition of a service plan """
    
    freemium_product_type: Optional[ReadAccountServiceInfoResponseServicePlanFreemiumProductType] = None

class ReadAccountServiceInfoResponseTargetServicePlanFreemiumProductType(Enum):
    Freyja = 'Freyja'
    Phoenix = 'Phoenix'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountServiceInfoResponseTargetServicePlan(DataClassJsonMixin):
    id: Optional[str] = None
    """ Internal identifier of a target service plan """
    
    name: Optional[str] = None
    """ Name of a target service plan """
    
    edition: Optional[str] = None
    """ Edition of a service plan """
    
    freemium_product_type: Optional[ReadAccountServiceInfoResponseTargetServicePlanFreemiumProductType] = None

class ReadAccountServiceInfoResponseBillingPlanDurationUnit(Enum):
    """ Duration period """
    
    Month = 'Month'
    Day = 'Day'

class ReadAccountServiceInfoResponseBillingPlanType(Enum):
    """ Billing plan type """
    
    Initial = 'Initial'
    Regular = 'Regular'
    Suspended = 'Suspended'
    Trial = 'Trial'
    TrialNoCC = 'TrialNoCC'
    Free = 'Free'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountServiceInfoResponseBillingPlan(DataClassJsonMixin):
    """ Information on account billing plan """
    
    id: Optional[str] = None
    """ Internal identifier of a billing plan """
    
    name: Optional[str] = None
    """ Billing plan name """
    
    duration_unit: Optional[ReadAccountServiceInfoResponseBillingPlanDurationUnit] = None
    """ Duration period """
    
    duration: Optional[int] = None
    """ Number of duration units """
    
    type: Optional[ReadAccountServiceInfoResponseBillingPlanType] = None
    """ Billing plan type """
    
    included_phone_lines: Optional[int] = None
    """ Included digital lines count """
    

class ReadAccountServiceInfoResponseServiceFeaturesItemFeatureName(Enum):
    """ Feature name """
    
    AccountFederation = 'AccountFederation'
    Archiver = 'Archiver'
    AutomaticCallRecordingMute = 'AutomaticCallRecordingMute'
    AutomaticInboundCallRecording = 'AutomaticInboundCallRecording'
    AutomaticOutboundCallRecording = 'AutomaticOutboundCallRecording'
    BlockedMessageForwarding = 'BlockedMessageForwarding'
    Calendar = 'Calendar'
    CallerIdControl = 'CallerIdControl'
    CallForwarding = 'CallForwarding'
    CallPark = 'CallPark'
    CallParkLocations = 'CallParkLocations'
    CallSupervision = 'CallSupervision'
    CallSwitch = 'CallSwitch'
    CallQualitySurvey = 'CallQualitySurvey'
    Conferencing = 'Conferencing'
    ConferencingNumber = 'ConferencingNumber'
    ConfigureDelegates = 'ConfigureDelegates'
    DeveloperPortal = 'DeveloperPortal'
    DND = 'DND'
    DynamicConference = 'DynamicConference'
    EmergencyAddressAutoUpdate = 'EmergencyAddressAutoUpdate'
    EmergencyCalling = 'EmergencyCalling'
    EncryptionAtRest = 'EncryptionAtRest'
    ExternalDirectoryIntegration = 'ExternalDirectoryIntegration'
    Fax = 'Fax'
    FaxReceiving = 'FaxReceiving'
    FreeSoftPhoneLines = 'FreeSoftPhoneLines'
    HDVoice = 'HDVoice'
    HipaaCompliance = 'HipaaCompliance'
    Intercom = 'Intercom'
    InternationalCalling = 'InternationalCalling'
    InternationalSMS = 'InternationalSMS'
    LinkedSoftphoneLines = 'LinkedSoftphoneLines'
    MMS = 'MMS'
    MobileVoipEmergencyCalling = 'MobileVoipEmergencyCalling'
    OnDemandCallRecording = 'OnDemandCallRecording'
    Pager = 'Pager'
    PagerReceiving = 'PagerReceiving'
    Paging = 'Paging'
    PasswordAuth = 'PasswordAuth'
    PromoMessage = 'PromoMessage'
    Reports = 'Reports'
    Presence = 'Presence'
    RCTeams = 'RCTeams'
    RingOut = 'RingOut'
    SalesForce = 'SalesForce'
    SharedLines = 'SharedLines'
    SingleExtensionUI = 'SingleExtensionUI'
    SiteCodes = 'SiteCodes'
    SMS = 'SMS'
    SMSReceiving = 'SMSReceiving'
    SoftPhoneUpdate = 'SoftPhoneUpdate'
    TelephonySessions = 'TelephonySessions'
    UserManagement = 'UserManagement'
    VideoConferencing = 'VideoConferencing'
    VoipCalling = 'VoipCalling'
    VoipCallingOnMobile = 'VoipCallingOnMobile'
    Voicemail = 'Voicemail'
    VoicemailToText = 'VoicemailToText'
    WebPhone = 'WebPhone'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountServiceInfoResponseServiceFeaturesItem(DataClassJsonMixin):
    feature_name: Optional[ReadAccountServiceInfoResponseServiceFeaturesItemFeatureName] = None
    """ Feature name """
    
    enabled: Optional[bool] = None
    """ Feature status, shows feature availability for the extension """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountServiceInfoResponseLimits(DataClassJsonMixin):
    """ Limits which are effective for the account """
    
    free_soft_phone_lines_per_extension: Optional[int] = None
    """ Max number of free softphone phone lines per user extension """
    
    meeting_size: Optional[int] = None
    """ Max number of participants in RingCentral meeting hosted by this account's user """
    
    cloud_recording_storage: Optional[int] = None
    """ Meetings recording cloud storage limitaion in Gb """
    
    max_monitored_extensions_per_user: Optional[int] = None
    """ Max number of extensions which can be included in the list of users monitored for Presence """
    
    max_extension_number_length: Optional[int] = 5
    """
    Max length of extension numbers of an account; the supported value is up to 8 symbols, depends
    on account type
    """
    
    site_code_length: Optional[int] = None
    """ Length of a site code """
    
    short_extension_number_length: Optional[int] = None
    """ Length of a short extension number """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountServiceInfoResponsePackage(DataClassJsonMixin):
    version: Optional[str] = None
    id: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountServiceInfoResponse(DataClassJsonMixin):
    uri: Optional[str] = None
    """ Canonical URI of the account Service Info resource """
    
    service_plan_name: Optional[str] = None
    """ Account Service Plan name """
    
    brand: Optional[ReadAccountServiceInfoResponseBrand] = None
    """ Information on account brand """
    
    contracted_country: Optional[ReadAccountServiceInfoResponseContractedCountry] = None
    """ Information on the contracted country of account """
    
    service_plan: Optional[ReadAccountServiceInfoResponseServicePlan] = None
    """ Information on account service plan """
    
    target_service_plan: Optional[ReadAccountServiceInfoResponseTargetServicePlan] = None
    billing_plan: Optional[ReadAccountServiceInfoResponseBillingPlan] = None
    """ Information on account billing plan """
    
    service_features: Optional[List[ReadAccountServiceInfoResponseServiceFeaturesItem]] = None
    """ Service features information, see Service Feature List """
    
    limits: Optional[ReadAccountServiceInfoResponseLimits] = None
    """ Limits which are effective for the account """
    
    package: Optional[ReadAccountServiceInfoResponsePackage] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListLanguagesResponseRecordsItem(DataClassJsonMixin):
    id: Optional[str] = None
    """ Internal identifier of a language """
    
    uri: Optional[str] = None
    """ Canonical URI of a language """
    
    greeting: Optional[bool] = None
    """ Indicates whether a language is available as greeting language """
    
    formatting_locale: Optional[bool] = None
    """ Indicates whether a language is available as formatting locale """
    
    locale_code: Optional[str] = None
    """ Localization code of a language """
    
    iso_code: Optional[str] = None
    """
    Country code according to the ISO standard, see [ISO
    3166](https://www.iso.org/iso-3166-country-codes.html)
    """
    
    name: Optional[str] = None
    """ Official name of a language """
    
    ui: Optional[bool] = None
    """ Indicates whether a language is available as UI language """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListLanguagesResponseNavigationFirstPage(DataClassJsonMixin):
    """ Canonical URI for the first page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListLanguagesResponseNavigationNextPage(DataClassJsonMixin):
    """ Canonical URI for the next page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListLanguagesResponseNavigationPreviousPage(DataClassJsonMixin):
    """ Canonical URI for the previous page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListLanguagesResponseNavigationLastPage(DataClassJsonMixin):
    """ Canonical URI for the last page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListLanguagesResponseNavigation(DataClassJsonMixin):
    """ Information on navigation """
    
    first_page: Optional[ListLanguagesResponseNavigationFirstPage] = None
    """ Canonical URI for the first page of the list """
    
    next_page: Optional[ListLanguagesResponseNavigationNextPage] = None
    """ Canonical URI for the next page of the list """
    
    previous_page: Optional[ListLanguagesResponseNavigationPreviousPage] = None
    """ Canonical URI for the previous page of the list """
    
    last_page: Optional[ListLanguagesResponseNavigationLastPage] = None
    """ Canonical URI for the last page of the list """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListLanguagesResponsePaging(DataClassJsonMixin):
    """ Information on paging """
    
    page: Optional[int] = None
    """
    The current page number. 1-indexed, so the first page is 1 by default. May be omitted if result
    is empty (because non-existent page was specified or perPage=0 was requested)
    """
    
    per_page: Optional[int] = None
    """
    Current page size, describes how many items are in each page. Default value is 100. Maximum
    value is 1000. If perPage value in the request is greater than 1000, the maximum value (1000)
    is applied
    """
    
    page_start: Optional[int] = None
    """
    The zero-based number of the first element on the current page. Omitted if the page is omitted
    or result is empty
    """
    
    page_end: Optional[int] = None
    """
    The zero-based index of the last element on the current page. Omitted if the page is omitted or
    result is empty
    """
    
    total_pages: Optional[int] = None
    """
    The total number of pages in a dataset. May be omitted for some resources due to performance
    reasons
    """
    
    total_elements: Optional[int] = None
    """
    The total number of elements in a dataset. May be omitted for some resource due to performance
    reasons
    """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListLanguagesResponse(DataClassJsonMixin):
    uri: Optional[str] = None
    """ Canonical URI of the language list resource """
    
    records: Optional[List[ListLanguagesResponseRecordsItem]] = None
    """ Language data """
    
    navigation: Optional[ListLanguagesResponseNavigation] = None
    """ Information on navigation """
    
    paging: Optional[ListLanguagesResponsePaging] = None
    """ Information on paging """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadLanguageResponse(DataClassJsonMixin):
    id: Optional[str] = None
    """ Internal identifier of a language """
    
    uri: Optional[str] = None
    """ Canonical URI of a language """
    
    greeting: Optional[bool] = None
    """ Indicates whether a language is available as greeting language """
    
    formatting_locale: Optional[bool] = None
    """ Indicates whether a language is available as formatting locale """
    
    locale_code: Optional[str] = None
    """ Localization code of a language """
    
    iso_code: Optional[str] = None
    """
    Country code according to the ISO standard, see [ISO
    3166](https://www.iso.org/iso-3166-country-codes.html)
    """
    
    name: Optional[str] = None
    """ Official name of a language """
    
    ui: Optional[bool] = None
    """ Indicates whether a language is available as UI language """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListCountriesResponseRecordsItem(DataClassJsonMixin):
    id: Optional[str] = None
    """ Internal identifier of a country """
    
    uri: Optional[str] = None
    """ Canonical URI of a country """
    
    calling_code: Optional[str] = None
    """
    Country calling code defined by ITU-T recommendations
    [E.123](https://www.itu.int/rec/T-REC-E.123-200102-I/en) and
    [E.164](https://www.itu.int/rec/T-REC-E.164-201011-I)
    """
    
    emergency_calling: Optional[bool] = None
    """ Emergency calling feature availability/emergency address requirement indicator """
    
    iso_code: Optional[str] = None
    """
    Country code according to the ISO standard, see [ISO
    3166](https://www.iso.org/iso-3166-country-codes.html)
    """
    
    name: Optional[str] = None
    """ Official name of a country """
    
    number_selling: Optional[bool] = None
    """ Determines whether phone numbers are available for a country """
    
    login_allowed: Optional[bool] = None
    """ Specifies whether login with the phone numbers of this country is enabled or not """
    
    signup_allowed: Optional[bool] = None
    """ Indicates whether signup/billing is allowed for a country """
    
    free_softphone_line: Optional[bool] = None
    """ Specifies if free phone line for softphone is available for a country or not """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListCountriesResponseNavigationFirstPage(DataClassJsonMixin):
    """ Canonical URI for the first page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListCountriesResponseNavigationNextPage(DataClassJsonMixin):
    """ Canonical URI for the next page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListCountriesResponseNavigationPreviousPage(DataClassJsonMixin):
    """ Canonical URI for the previous page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListCountriesResponseNavigationLastPage(DataClassJsonMixin):
    """ Canonical URI for the last page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListCountriesResponseNavigation(DataClassJsonMixin):
    """ Information on navigation """
    
    first_page: Optional[ListCountriesResponseNavigationFirstPage] = None
    """ Canonical URI for the first page of the list """
    
    next_page: Optional[ListCountriesResponseNavigationNextPage] = None
    """ Canonical URI for the next page of the list """
    
    previous_page: Optional[ListCountriesResponseNavigationPreviousPage] = None
    """ Canonical URI for the previous page of the list """
    
    last_page: Optional[ListCountriesResponseNavigationLastPage] = None
    """ Canonical URI for the last page of the list """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListCountriesResponsePaging(DataClassJsonMixin):
    """ Information on paging """
    
    page: Optional[int] = None
    """
    The current page number. 1-indexed, so the first page is 1 by default. May be omitted if result
    is empty (because non-existent page was specified or perPage=0 was requested)
    """
    
    per_page: Optional[int] = None
    """
    Current page size, describes how many items are in each page. Default value is 100. Maximum
    value is 1000. If perPage value in the request is greater than 1000, the maximum value (1000)
    is applied
    """
    
    page_start: Optional[int] = None
    """
    The zero-based number of the first element on the current page. Omitted if the page is omitted
    or result is empty
    """
    
    page_end: Optional[int] = None
    """
    The zero-based index of the last element on the current page. Omitted if the page is omitted or
    result is empty
    """
    
    total_pages: Optional[int] = None
    """
    The total number of pages in a dataset. May be omitted for some resources due to performance
    reasons
    """
    
    total_elements: Optional[int] = None
    """
    The total number of elements in a dataset. May be omitted for some resource due to performance
    reasons
    """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListCountriesResponse(DataClassJsonMixin):
    """
    Required Properties:
     - navigation
     - paging
     - records
    
    Generated by Python OpenAPI Parser
    """
    
    records: List[ListCountriesResponseRecordsItem]
    """ List of countries with the country data """
    
    navigation: ListCountriesResponseNavigation
    """ Information on navigation """
    
    paging: ListCountriesResponsePaging
    """ Information on paging """
    
    uri: Optional[str] = None
    """ Link to the list of countries supported """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadCountryResponse(DataClassJsonMixin):
    id: Optional[str] = None
    """ Internal identifier of a country """
    
    uri: Optional[str] = None
    """ Canonical URI of a country """
    
    calling_code: Optional[str] = None
    """
    Country calling code defined by ITU-T recommendations
    [E.123](https://www.itu.int/rec/T-REC-E.123-200102-I/en) and
    [E.164](https://www.itu.int/rec/T-REC-E.164-201011-I)
    """
    
    emergency_calling: Optional[bool] = None
    """ Emergency calling feature availability/emergency address requirement indicator """
    
    iso_code: Optional[str] = None
    """
    Country code according to the ISO standard, see [ISO
    3166](https://www.iso.org/iso-3166-country-codes.html)
    """
    
    name: Optional[str] = None
    """ Official name of a country """
    
    number_selling: Optional[bool] = None
    """ Determines whether phone numbers are available for a country """
    
    login_allowed: Optional[bool] = None
    """ Specifies whether login with the phone numbers of this country is enabled or not """
    
    signup_allowed: Optional[bool] = None
    """ Indicates whether signup/billing is allowed for a country """
    
    free_softphone_line: Optional[bool] = None
    """ Specifies if free phone line for softphone is available for a country or not """
    

class ListLocationsOrderBy(Enum):
    Npa = 'Npa'
    City = 'City'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListLocationsResponseRecordsItemState(DataClassJsonMixin):
    """ Information on the state this location belongs to """
    
    id: Optional[str] = None
    """ Internal identifier of a state """
    
    uri: Optional[str] = None
    """ Link to a state resource """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListLocationsResponseRecordsItem(DataClassJsonMixin):
    uri: Optional[str] = None
    """ Canonical URI of a location """
    
    area_code: Optional[str] = None
    """ Area code of the location """
    
    city: Optional[str] = None
    """ Official name of the city, belonging to the certain state """
    
    npa: Optional[str] = None
    """
    Area code of the location (3-digit usually), according to the NANP number format, that can be
    summarized as NPA-NXX-xxxx and covers Canada, the United States, parts of the Caribbean Sea,
    and some Atlantic and Pacific islands. See for details North American Numbering Plan
    """
    
    nxx: Optional[str] = None
    """
    Central office code of the location, according to the NANP number format, that can be
    summarized as NPA-NXX-xxxx and covers Canada, the United States, parts of the Caribbean Sea,
    and some Atlantic and Pacific islands. See for details North American Numbering Plan
    """
    
    state: Optional[ListLocationsResponseRecordsItemState] = None
    """ Information on the state this location belongs to """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListLocationsResponseNavigationFirstPage(DataClassJsonMixin):
    """ Canonical URI for the first page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListLocationsResponseNavigationNextPage(DataClassJsonMixin):
    """ Canonical URI for the next page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListLocationsResponseNavigationPreviousPage(DataClassJsonMixin):
    """ Canonical URI for the previous page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListLocationsResponseNavigationLastPage(DataClassJsonMixin):
    """ Canonical URI for the last page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListLocationsResponseNavigation(DataClassJsonMixin):
    """ Information on navigation """
    
    first_page: Optional[ListLocationsResponseNavigationFirstPage] = None
    """ Canonical URI for the first page of the list """
    
    next_page: Optional[ListLocationsResponseNavigationNextPage] = None
    """ Canonical URI for the next page of the list """
    
    previous_page: Optional[ListLocationsResponseNavigationPreviousPage] = None
    """ Canonical URI for the previous page of the list """
    
    last_page: Optional[ListLocationsResponseNavigationLastPage] = None
    """ Canonical URI for the last page of the list """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListLocationsResponsePaging(DataClassJsonMixin):
    """ Information on paging """
    
    page: Optional[int] = None
    """
    The current page number. 1-indexed, so the first page is 1 by default. May be omitted if result
    is empty (because non-existent page was specified or perPage=0 was requested)
    """
    
    per_page: Optional[int] = None
    """
    Current page size, describes how many items are in each page. Default value is 100. Maximum
    value is 1000. If perPage value in the request is greater than 1000, the maximum value (1000)
    is applied
    """
    
    page_start: Optional[int] = None
    """
    The zero-based number of the first element on the current page. Omitted if the page is omitted
    or result is empty
    """
    
    page_end: Optional[int] = None
    """
    The zero-based index of the last element on the current page. Omitted if the page is omitted or
    result is empty
    """
    
    total_pages: Optional[int] = None
    """
    The total number of pages in a dataset. May be omitted for some resources due to performance
    reasons
    """
    
    total_elements: Optional[int] = None
    """
    The total number of elements in a dataset. May be omitted for some resource due to performance
    reasons
    """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListLocationsResponse(DataClassJsonMixin):
    """
    Required Properties:
     - navigation
     - paging
    
    Generated by Python OpenAPI Parser
    """
    
    navigation: ListLocationsResponseNavigation
    """ Information on navigation """
    
    paging: ListLocationsResponsePaging
    """ Information on paging """
    
    uri: Optional[str] = None
    """ Link to the location list resource """
    
    records: Optional[List[ListLocationsResponseRecordsItem]] = None
    """ List of locations """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListStatesResponseRecordsItemCountry(DataClassJsonMixin):
    """ Information on a country the state belongs to """
    
    id: Optional[str] = None
    """ Internal identifier of a state """
    
    uri: Optional[str] = None
    """ Canonical URI of a state """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListStatesResponseRecordsItem(DataClassJsonMixin):
    id: Optional[str] = None
    """ Internal identifier of a state """
    
    uri: Optional[str] = None
    """ Canonical URI of a state """
    
    country: Optional[ListStatesResponseRecordsItemCountry] = None
    """ Information on a country the state belongs to """
    
    iso_code: Optional[str] = None
    """ Short code for a state (2-letter usually) """
    
    name: Optional[str] = None
    """ Official name of a state """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListStatesResponseNavigationFirstPage(DataClassJsonMixin):
    """ Canonical URI for the first page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListStatesResponseNavigationNextPage(DataClassJsonMixin):
    """ Canonical URI for the next page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListStatesResponseNavigationPreviousPage(DataClassJsonMixin):
    """ Canonical URI for the previous page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListStatesResponseNavigationLastPage(DataClassJsonMixin):
    """ Canonical URI for the last page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListStatesResponseNavigation(DataClassJsonMixin):
    """ Information on navigation """
    
    first_page: Optional[ListStatesResponseNavigationFirstPage] = None
    """ Canonical URI for the first page of the list """
    
    next_page: Optional[ListStatesResponseNavigationNextPage] = None
    """ Canonical URI for the next page of the list """
    
    previous_page: Optional[ListStatesResponseNavigationPreviousPage] = None
    """ Canonical URI for the previous page of the list """
    
    last_page: Optional[ListStatesResponseNavigationLastPage] = None
    """ Canonical URI for the last page of the list """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListStatesResponsePaging(DataClassJsonMixin):
    """ Information on paging """
    
    page: Optional[int] = None
    """
    The current page number. 1-indexed, so the first page is 1 by default. May be omitted if result
    is empty (because non-existent page was specified or perPage=0 was requested)
    """
    
    per_page: Optional[int] = None
    """
    Current page size, describes how many items are in each page. Default value is 100. Maximum
    value is 1000. If perPage value in the request is greater than 1000, the maximum value (1000)
    is applied
    """
    
    page_start: Optional[int] = None
    """
    The zero-based number of the first element on the current page. Omitted if the page is omitted
    or result is empty
    """
    
    page_end: Optional[int] = None
    """
    The zero-based index of the last element on the current page. Omitted if the page is omitted or
    result is empty
    """
    
    total_pages: Optional[int] = None
    """
    The total number of pages in a dataset. May be omitted for some resources due to performance
    reasons
    """
    
    total_elements: Optional[int] = None
    """
    The total number of elements in a dataset. May be omitted for some resource due to performance
    reasons
    """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListStatesResponse(DataClassJsonMixin):
    uri: Optional[str] = None
    """ Link to the states list resource """
    
    records: Optional[List[ListStatesResponseRecordsItem]] = None
    """ List of states """
    
    navigation: Optional[ListStatesResponseNavigation] = None
    """ Information on navigation """
    
    paging: Optional[ListStatesResponsePaging] = None
    """ Information on paging """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadStateResponseCountry(DataClassJsonMixin):
    """ Information on a country the state belongs to """
    
    id: Optional[str] = None
    """ Internal identifier of a state """
    
    uri: Optional[str] = None
    """ Canonical URI of a state """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadStateResponse(DataClassJsonMixin):
    id: Optional[str] = None
    """ Internal identifier of a state """
    
    uri: Optional[str] = None
    """ Canonical URI of a state """
    
    country: Optional[ReadStateResponseCountry] = None
    """ Information on a country the state belongs to """
    
    iso_code: Optional[str] = None
    """ Short code for a state (2-letter usually) """
    
    name: Optional[str] = None
    """ Official name of a state """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListTimezonesResponseRecordsItem(DataClassJsonMixin):
    id: Optional[str] = None
    """ Internal identifier of a timezone """
    
    uri: Optional[str] = None
    """ Canonical URI of a timezone """
    
    name: Optional[str] = None
    """ Short name of a timezone """
    
    description: Optional[str] = None
    """ Description of a timezone """
    
    bias: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListTimezonesResponseNavigationFirstPage(DataClassJsonMixin):
    """ Canonical URI for the first page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListTimezonesResponseNavigationNextPage(DataClassJsonMixin):
    """ Canonical URI for the next page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListTimezonesResponseNavigationPreviousPage(DataClassJsonMixin):
    """ Canonical URI for the previous page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListTimezonesResponseNavigationLastPage(DataClassJsonMixin):
    """ Canonical URI for the last page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListTimezonesResponseNavigation(DataClassJsonMixin):
    """ Information on navigation """
    
    first_page: Optional[ListTimezonesResponseNavigationFirstPage] = None
    """ Canonical URI for the first page of the list """
    
    next_page: Optional[ListTimezonesResponseNavigationNextPage] = None
    """ Canonical URI for the next page of the list """
    
    previous_page: Optional[ListTimezonesResponseNavigationPreviousPage] = None
    """ Canonical URI for the previous page of the list """
    
    last_page: Optional[ListTimezonesResponseNavigationLastPage] = None
    """ Canonical URI for the last page of the list """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListTimezonesResponsePaging(DataClassJsonMixin):
    """ Information on paging """
    
    page: Optional[int] = None
    """
    The current page number. 1-indexed, so the first page is 1 by default. May be omitted if result
    is empty (because non-existent page was specified or perPage=0 was requested)
    """
    
    per_page: Optional[int] = None
    """
    Current page size, describes how many items are in each page. Default value is 100. Maximum
    value is 1000. If perPage value in the request is greater than 1000, the maximum value (1000)
    is applied
    """
    
    page_start: Optional[int] = None
    """
    The zero-based number of the first element on the current page. Omitted if the page is omitted
    or result is empty
    """
    
    page_end: Optional[int] = None
    """
    The zero-based index of the last element on the current page. Omitted if the page is omitted or
    result is empty
    """
    
    total_pages: Optional[int] = None
    """
    The total number of pages in a dataset. May be omitted for some resources due to performance
    reasons
    """
    
    total_elements: Optional[int] = None
    """
    The total number of elements in a dataset. May be omitted for some resource due to performance
    reasons
    """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListTimezonesResponse(DataClassJsonMixin):
    """
    Required Properties:
     - navigation
     - paging
     - records
    
    Generated by Python OpenAPI Parser
    """
    
    records: List[ListTimezonesResponseRecordsItem]
    """ List of timezones """
    
    navigation: ListTimezonesResponseNavigation
    """ Information on navigation """
    
    paging: ListTimezonesResponsePaging
    """ Information on paging """
    
    uri: Optional[str] = None
    """ Link to the timezone list resource """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadTimezoneResponse(DataClassJsonMixin):
    id: Optional[str] = None
    """ Internal identifier of a timezone """
    
    uri: Optional[str] = None
    """ Canonical URI of a timezone """
    
    name: Optional[str] = None
    """ Short name of a timezone """
    
    description: Optional[str] = None
    """ Description of a timezone """
    
    bias: Optional[str] = None

class ListAccountPhoneNumbersUsageTypeItem(Enum):
    MainCompanyNumber = 'MainCompanyNumber'
    AdditionalCompanyNumber = 'AdditionalCompanyNumber'
    CompanyNumber = 'CompanyNumber'
    DirectNumber = 'DirectNumber'
    CompanyFaxNumber = 'CompanyFaxNumber'
    ForwardedNumber = 'ForwardedNumber'
    ForwardedCompanyNumber = 'ForwardedCompanyNumber'
    ContactCenterNumber = 'ContactCenterNumber'
    ConferencingNumber = 'ConferencingNumber'
    MeetingsNumber = 'MeetingsNumber'
    BusinessMobileNumber = 'BusinessMobileNumber'

class ListAccountPhoneNumbersStatus(Enum):
    Normal = 'Normal'
    Pending = 'Pending'
    PortedIn = 'PortedIn'
    Temporary = 'Temporary'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListAccountPhoneNumbersResponseRecordsItemCountry(DataClassJsonMixin):
    """ Brief information on a phone number country """
    
    id: Optional[str] = None
    """ Internal identifier of a home country """
    
    uri: Optional[str] = None
    """ Canonical URI of a home country """
    
    name: Optional[str] = None
    """ Official name of a home country """
    
    iso_code: Optional[str] = None
    """ ISO code of a country """
    
    calling_code: Optional[str] = None
    """ Calling code of a country """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListAccountPhoneNumbersResponseRecordsItemExtension(DataClassJsonMixin):
    """
    Information on the extension, to which the phone number is assigned. Returned only for the
    request of Account phone number list
    
    Generated by Python OpenAPI Parser
    """
    
    id: Optional[str] = None
    """ Internal identifier of an extension """
    
    uri: Optional[str] = None
    """ Canonical URI of an extension """
    
    extension_number: Optional[str] = None
    """ Number of department extension """
    
    partner_id: Optional[str] = None
    """
    For Partner Applications Internal identifier of an extension created by partner. The
    RingCentral supports the mapping of accounts and stores the corresponding account ID/extension
    ID for each partner ID of a client application. In request URIs partner IDs are accepted
    instead of regular RingCentral native IDs as path parameters using pid = XXX clause. Though in
    response URIs contain the corresponding account IDs and extension IDs. In all request and
    response bodies these values are reflected via partnerId attributes of account and extension
    """
    

class ListAccountPhoneNumbersResponseRecordsItemPaymentType(Enum):
    """
    Payment type. 'External' is returned for forwarded numbers which are not terminated in the
    RingCentral phone system
    
    Generated by Python OpenAPI Parser
    """
    
    External = 'External'
    TollFree = 'TollFree'
    Local = 'Local'
    BusinessMobileNumberProvider = 'BusinessMobileNumberProvider'

class ListAccountPhoneNumbersResponseRecordsItemType(Enum):
    """ Phone number type """
    
    VoiceFax = 'VoiceFax'
    FaxOnly = 'FaxOnly'
    VoiceOnly = 'VoiceOnly'

class ListAccountPhoneNumbersResponseRecordsItemUsageType(Enum):
    """
    Usage type of a phone number. Usage type of a phone number. Numbers of 'NumberPool' type wont't
    be returned for phone number list requests
    
    Generated by Python OpenAPI Parser
    """
    
    MainCompanyNumber = 'MainCompanyNumber'
    AdditionalCompanyNumber = 'AdditionalCompanyNumber'
    CompanyNumber = 'CompanyNumber'
    DirectNumber = 'DirectNumber'
    CompanyFaxNumber = 'CompanyFaxNumber'
    ForwardedNumber = 'ForwardedNumber'
    ForwardedCompanyNumber = 'ForwardedCompanyNumber'
    ContactCenterNumber = 'ContactCenterNumber'
    ConferencingNumber = 'ConferencingNumber'
    MeetingsNumber = 'MeetingsNumber'
    NumberPool = 'NumberPool'
    BusinessMobileNumber = 'BusinessMobileNumber'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListAccountPhoneNumbersResponseRecordsItemTemporaryNumber(DataClassJsonMixin):
    """ Temporary phone number, if any. Returned for phone numbers in `Pending` porting status only """
    
    id: Optional[str] = None
    """ Temporary phone number identifier """
    
    phone_number: Optional[str] = None
    """
    Temporary phone number in [E.164](https://www.itu.int/rec/T-REC-E.164-201011-I) (with '+' sign)
    format
    """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListAccountPhoneNumbersResponseRecordsItemContactCenterProvider(DataClassJsonMixin):
    """
    CCRN (Contact Center Routing Number) provider. If not specified then the default value
    'InContact/North America' is used, its ID is '1'
    
    Generated by Python OpenAPI Parser
    """
    
    id: Optional[str] = None
    """ Internal identifier of the provider """
    
    name: Optional[str] = None
    """ Provider's name """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListAccountPhoneNumbersResponseRecordsItem(DataClassJsonMixin):
    uri: Optional[str] = None
    """ Link to a company phone number resource """
    
    id: Optional[int] = None
    """ Internal identifier of a phone number """
    
    country: Optional[ListAccountPhoneNumbersResponseRecordsItemCountry] = None
    """ Brief information on a phone number country """
    
    extension: Optional[ListAccountPhoneNumbersResponseRecordsItemExtension] = None
    """
    Information on the extension, to which the phone number is assigned. Returned only for the
    request of Account phone number list
    """
    
    label: Optional[str] = None
    """ Custom user name of a phone number, if any """
    
    location: Optional[str] = None
    """ Location (City, State). Filled for local US numbers """
    
    payment_type: Optional[ListAccountPhoneNumbersResponseRecordsItemPaymentType] = None
    """
    Payment type. 'External' is returned for forwarded numbers which are not terminated in the
    RingCentral phone system
    """
    
    phone_number: Optional[str] = None
    """ Phone number """
    
    status: Optional[str] = None
    """
    Status of a phone number. If the value is 'Normal', the phone number is ready to be used.
    Otherwise it is an external number not yet ported to RingCentral
    """
    
    type: Optional[ListAccountPhoneNumbersResponseRecordsItemType] = None
    """ Phone number type """
    
    usage_type: Optional[ListAccountPhoneNumbersResponseRecordsItemUsageType] = None
    """
    Usage type of a phone number. Usage type of a phone number. Numbers of 'NumberPool' type wont't
    be returned for phone number list requests
    """
    
    temporary_number: Optional[ListAccountPhoneNumbersResponseRecordsItemTemporaryNumber] = None
    """ Temporary phone number, if any. Returned for phone numbers in `Pending` porting status only """
    
    contact_center_provider: Optional[ListAccountPhoneNumbersResponseRecordsItemContactCenterProvider] = None
    """
    CCRN (Contact Center Routing Number) provider. If not specified then the default value
    'InContact/North America' is used, its ID is '1'
    """
    
    vanity_pattern: Optional[str] = None
    """
    Vanity pattern for this number. Returned only when vanity search option is requested. Vanity
    pattern corresponds to request parameters nxx plus line or numberPattern
    """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListAccountPhoneNumbersResponseNavigationFirstPage(DataClassJsonMixin):
    """ Canonical URI for the first page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListAccountPhoneNumbersResponseNavigationNextPage(DataClassJsonMixin):
    """ Canonical URI for the next page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListAccountPhoneNumbersResponseNavigationPreviousPage(DataClassJsonMixin):
    """ Canonical URI for the previous page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListAccountPhoneNumbersResponseNavigationLastPage(DataClassJsonMixin):
    """ Canonical URI for the last page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListAccountPhoneNumbersResponseNavigation(DataClassJsonMixin):
    """ Information on navigation """
    
    first_page: Optional[ListAccountPhoneNumbersResponseNavigationFirstPage] = None
    """ Canonical URI for the first page of the list """
    
    next_page: Optional[ListAccountPhoneNumbersResponseNavigationNextPage] = None
    """ Canonical URI for the next page of the list """
    
    previous_page: Optional[ListAccountPhoneNumbersResponseNavigationPreviousPage] = None
    """ Canonical URI for the previous page of the list """
    
    last_page: Optional[ListAccountPhoneNumbersResponseNavigationLastPage] = None
    """ Canonical URI for the last page of the list """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListAccountPhoneNumbersResponsePaging(DataClassJsonMixin):
    """ Information on paging """
    
    page: Optional[int] = None
    """
    The current page number. 1-indexed, so the first page is 1 by default. May be omitted if result
    is empty (because non-existent page was specified or perPage=0 was requested)
    """
    
    per_page: Optional[int] = None
    """
    Current page size, describes how many items are in each page. Default value is 100. Maximum
    value is 1000. If perPage value in the request is greater than 1000, the maximum value (1000)
    is applied
    """
    
    page_start: Optional[int] = None
    """
    The zero-based number of the first element on the current page. Omitted if the page is omitted
    or result is empty
    """
    
    page_end: Optional[int] = None
    """
    The zero-based index of the last element on the current page. Omitted if the page is omitted or
    result is empty
    """
    
    total_pages: Optional[int] = None
    """
    The total number of pages in a dataset. May be omitted for some resources due to performance
    reasons
    """
    
    total_elements: Optional[int] = None
    """
    The total number of elements in a dataset. May be omitted for some resource due to performance
    reasons
    """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListAccountPhoneNumbersResponse(DataClassJsonMixin):
    uri: Optional[str] = None
    """ Link to the list of account phone numbers """
    
    records: Optional[List[ListAccountPhoneNumbersResponseRecordsItem]] = None
    """ List of account phone numbers """
    
    navigation: Optional[ListAccountPhoneNumbersResponseNavigation] = None
    """ Information on navigation """
    
    paging: Optional[ListAccountPhoneNumbersResponsePaging] = None
    """ Information on paging """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountPhoneNumberResponseCountry(DataClassJsonMixin):
    """ Brief information on a phone number country """
    
    id: Optional[str] = None
    """ Internal identifier of a home country """
    
    uri: Optional[str] = None
    """ Canonical URI of a home country """
    
    name: Optional[str] = None
    """ Official name of a home country """
    
    iso_code: Optional[str] = None
    """ ISO code of a country """
    
    calling_code: Optional[str] = None
    """ Calling code of a country """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountPhoneNumberResponseExtension(DataClassJsonMixin):
    """
    Information on the extension, to which the phone number is assigned. Returned only for the
    request of Account phone number list
    
    Generated by Python OpenAPI Parser
    """
    
    id: Optional[str] = None
    """ Internal identifier of an extension """
    
    uri: Optional[str] = None
    """ Canonical URI of an extension """
    
    extension_number: Optional[str] = None
    """ Number of department extension """
    
    partner_id: Optional[str] = None
    """
    For Partner Applications Internal identifier of an extension created by partner. The
    RingCentral supports the mapping of accounts and stores the corresponding account ID/extension
    ID for each partner ID of a client application. In request URIs partner IDs are accepted
    instead of regular RingCentral native IDs as path parameters using pid = XXX clause. Though in
    response URIs contain the corresponding account IDs and extension IDs. In all request and
    response bodies these values are reflected via partnerId attributes of account and extension
    """
    

class ReadAccountPhoneNumberResponsePaymentType(Enum):
    """
    Payment type. 'External' is returned for forwarded numbers which are not terminated in the
    RingCentral phone system
    
    Generated by Python OpenAPI Parser
    """
    
    External = 'External'
    TollFree = 'TollFree'
    Local = 'Local'
    BusinessMobileNumberProvider = 'BusinessMobileNumberProvider'

class ReadAccountPhoneNumberResponseType(Enum):
    """ Phone number type """
    
    VoiceFax = 'VoiceFax'
    FaxOnly = 'FaxOnly'
    VoiceOnly = 'VoiceOnly'

class ReadAccountPhoneNumberResponseUsageType(Enum):
    """
    Usage type of a phone number. Usage type of a phone number. Numbers of 'NumberPool' type wont't
    be returned for phone number list requests
    
    Generated by Python OpenAPI Parser
    """
    
    MainCompanyNumber = 'MainCompanyNumber'
    AdditionalCompanyNumber = 'AdditionalCompanyNumber'
    CompanyNumber = 'CompanyNumber'
    DirectNumber = 'DirectNumber'
    CompanyFaxNumber = 'CompanyFaxNumber'
    ForwardedNumber = 'ForwardedNumber'
    ForwardedCompanyNumber = 'ForwardedCompanyNumber'
    ContactCenterNumber = 'ContactCenterNumber'
    ConferencingNumber = 'ConferencingNumber'
    MeetingsNumber = 'MeetingsNumber'
    NumberPool = 'NumberPool'
    BusinessMobileNumber = 'BusinessMobileNumber'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountPhoneNumberResponseTemporaryNumber(DataClassJsonMixin):
    """ Temporary phone number, if any. Returned for phone numbers in `Pending` porting status only """
    
    id: Optional[str] = None
    """ Temporary phone number identifier """
    
    phone_number: Optional[str] = None
    """
    Temporary phone number in [E.164](https://www.itu.int/rec/T-REC-E.164-201011-I) (with '+' sign)
    format
    """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountPhoneNumberResponseContactCenterProvider(DataClassJsonMixin):
    """
    CCRN (Contact Center Routing Number) provider. If not specified then the default value
    'InContact/North America' is used, its ID is '1'
    
    Generated by Python OpenAPI Parser
    """
    
    id: Optional[str] = None
    """ Internal identifier of the provider """
    
    name: Optional[str] = None
    """ Provider's name """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadAccountPhoneNumberResponse(DataClassJsonMixin):
    uri: Optional[str] = None
    """ Link to a company phone number resource """
    
    id: Optional[int] = None
    """ Internal identifier of a phone number """
    
    country: Optional[ReadAccountPhoneNumberResponseCountry] = None
    """ Brief information on a phone number country """
    
    extension: Optional[ReadAccountPhoneNumberResponseExtension] = None
    """
    Information on the extension, to which the phone number is assigned. Returned only for the
    request of Account phone number list
    """
    
    label: Optional[str] = None
    """ Custom user name of a phone number, if any """
    
    location: Optional[str] = None
    """ Location (City, State). Filled for local US numbers """
    
    payment_type: Optional[ReadAccountPhoneNumberResponsePaymentType] = None
    """
    Payment type. 'External' is returned for forwarded numbers which are not terminated in the
    RingCentral phone system
    """
    
    phone_number: Optional[str] = None
    """ Phone number """
    
    status: Optional[str] = None
    """
    Status of a phone number. If the value is 'Normal', the phone number is ready to be used.
    Otherwise it is an external number not yet ported to RingCentral
    """
    
    type: Optional[ReadAccountPhoneNumberResponseType] = None
    """ Phone number type """
    
    usage_type: Optional[ReadAccountPhoneNumberResponseUsageType] = None
    """
    Usage type of a phone number. Usage type of a phone number. Numbers of 'NumberPool' type wont't
    be returned for phone number list requests
    """
    
    temporary_number: Optional[ReadAccountPhoneNumberResponseTemporaryNumber] = None
    """ Temporary phone number, if any. Returned for phone numbers in `Pending` porting status only """
    
    contact_center_provider: Optional[ReadAccountPhoneNumberResponseContactCenterProvider] = None
    """
    CCRN (Contact Center Routing Number) provider. If not specified then the default value
    'InContact/North America' is used, its ID is '1'
    """
    
    vanity_pattern: Optional[str] = None
    """
    Vanity pattern for this number. Returned only when vanity search option is requested. Vanity
    pattern corresponds to request parameters nxx plus line or numberPattern
    """
    

class ListExtensionsStatusItem(Enum):
    Enabled = 'Enabled'
    Disabled = 'Disabled'
    NotActivated = 'NotActivated'
    Unassigned = 'Unassigned'

class ListExtensionsTypeItem(Enum):
    User = 'User'
    FaxUser = 'FaxUser'
    VirtualUser = 'VirtualUser'
    DigitalUser = 'DigitalUser'
    Department = 'Department'
    Announcement = 'Announcement'
    Voicemail = 'Voicemail'
    SharedLinesGroup = 'SharedLinesGroup'
    PagingOnly = 'PagingOnly'
    IvrMenu = 'IvrMenu'
    ApplicationExtension = 'ApplicationExtension'
    ParkLocation = 'ParkLocation'
    Limited = 'Limited'
    Bot = 'Bot'
    ProxyAdmin = 'ProxyAdmin'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemAccount(DataClassJsonMixin):
    """ Account information """
    
    id: Optional[str] = None
    """ Internal identifier of an account """
    
    uri: Optional[str] = None
    """ Canonical URI of an account """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemContactBusinessAddress(DataClassJsonMixin):
    """ Business address of extension user company """
    
    country: Optional[str] = None
    """ Country name of an extension user company """
    
    state: Optional[str] = None
    """ State/province name of an extension user company. Mandatory for the USA, UK and Canada """
    
    city: Optional[str] = None
    """ City name of an extension user company """
    
    street: Optional[str] = None
    """ Street address of an extension user company """
    
    zip: Optional[str] = None
    """ Zip code of an extension user company """
    

class ListExtensionsResponseRecordsItemContactPronouncedNameType(Enum):
    """
    Voice name type. 'Default' - default extension name; first name and last name specified in user
    profile; 'TextToSpeech' - custom text; user name spelled the way it sounds and specified by
    user; 'Recorded' - custom audio, user name recorded in user's own voice (supported only for
    extension retrieval)
    
    Generated by Python OpenAPI Parser
    """
    
    Default = 'Default'
    TextToSpeech = 'TextToSpeech'
    Recorded = 'Recorded'

class ListExtensionsResponseRecordsItemContactPronouncedNamePromptContentType(Enum):
    """ Content media type """
    
    AudioMpeg = 'audio/mpeg'
    AudioWav = 'audio/wav'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemContactPronouncedNamePrompt(DataClassJsonMixin):
    id: Optional[str] = None
    content_uri: Optional[str] = None
    """ Link to a prompt resource """
    
    content_type: Optional[ListExtensionsResponseRecordsItemContactPronouncedNamePromptContentType] = None
    """ Content media type """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemContactPronouncedName(DataClassJsonMixin):
    type: Optional[ListExtensionsResponseRecordsItemContactPronouncedNameType] = None
    """
    Voice name type. 'Default' - default extension name; first name and last name specified in user
    profile; 'TextToSpeech' - custom text; user name spelled the way it sounds and specified by
    user; 'Recorded' - custom audio, user name recorded in user's own voice (supported only for
    extension retrieval)
    """
    
    text: Optional[str] = None
    """ Custom text """
    
    prompt: Optional[ListExtensionsResponseRecordsItemContactPronouncedNamePrompt] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemContact(DataClassJsonMixin):
    """ Contact detailed information """
    
    first_name: Optional[str] = None
    """ For User extension type only. Extension user first name """
    
    last_name: Optional[str] = None
    """ For User extension type only. Extension user last name """
    
    company: Optional[str] = None
    """ Extension user company name """
    
    job_title: Optional[str] = None
    email: Optional[str] = None
    """ Email of extension user """
    
    business_phone: Optional[str] = None
    """
    Extension user contact phone number in [E.164](https://www.itu.int/rec/T-REC-E.164-201011-I)
    (with '+' sign) format
    """
    
    mobile_phone: Optional[str] = None
    """
    Extension user mobile (**non** Toll Free) phone number in
    [E.164](https://www.itu.int/rec/T-REC-E.164-201011-I) (with '+' sign) format
    """
    
    business_address: Optional[ListExtensionsResponseRecordsItemContactBusinessAddress] = None
    """ Business address of extension user company """
    
    email_as_login_name: Optional[bool] = 'False'
    """
    If 'True' then contact email is enabled as login name for this user. Please note that email
    should be unique in this case.
    """
    
    pronounced_name: Optional[ListExtensionsResponseRecordsItemContactPronouncedName] = None
    department: Optional[str] = None
    """ Extension user department, if any """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemCustomFieldsItem(DataClassJsonMixin):
    id: Optional[str] = None
    """ Internal identifier of a custom field """
    
    value: Optional[str] = None
    """ Custom field value """
    
    display_name: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemDepartmentsItem(DataClassJsonMixin):
    id: Optional[str] = None
    """ Internal identifier of a department extension """
    
    uri: Optional[str] = None
    """ Canonical URI of a department extension """
    
    extension_number: Optional[str] = None
    """ Number of a department extension """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemPermissionsAdmin(DataClassJsonMixin):
    """ Admin permission """
    
    enabled: Optional[bool] = None
    """ Specifies if a permission is enabled or not """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemPermissionsInternationalCalling(DataClassJsonMixin):
    """ International Calling permission """
    
    enabled: Optional[bool] = None
    """ Specifies if a permission is enabled or not """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemPermissions(DataClassJsonMixin):
    """
    Extension permissions, corresponding to the Service Web permissions 'Admin' and
    'InternationalCalling'
    
    Generated by Python OpenAPI Parser
    """
    
    admin: Optional[ListExtensionsResponseRecordsItemPermissionsAdmin] = None
    """ Admin permission """
    
    international_calling: Optional[ListExtensionsResponseRecordsItemPermissionsInternationalCalling] = None
    """ International Calling permission """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemProfileImageScalesItem(DataClassJsonMixin):
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemProfileImage(DataClassJsonMixin):
    """
    Information on profile image
    
    Required Properties:
     - uri
    
    Generated by Python OpenAPI Parser
    """
    
    uri: str
    """ Link to a profile image. If an image is not uploaded for an extension, only uri is returned """
    
    etag: Optional[str] = None
    """ Identifier of an image """
    
    last_modified: Optional[datetime] = field(metadata=config(encoder=datetime.isoformat, decoder=datetime_decoder(datetime)), default=None)
    """
    The datetime when an image was last updated in ISO 8601 format, for example
    2016-03-10T18:07:52.534Z
    """
    
    content_type: Optional[str] = None
    """ The type of an image """
    
    scales: Optional[List[ListExtensionsResponseRecordsItemProfileImageScalesItem]] = None
    """ List of URIs to profile images in different dimensions """
    

class ListExtensionsResponseRecordsItemReferencesItemType(Enum):
    """ Type of external identifier """
    
    PartnerId = 'PartnerId'
    CustomerDirectoryId = 'CustomerDirectoryId'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemReferencesItem(DataClassJsonMixin):
    ref: Optional[str] = None
    """ Non-RC identifier of an extension """
    
    type: Optional[ListExtensionsResponseRecordsItemReferencesItemType] = None
    """ Type of external identifier """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemRolesItem(DataClassJsonMixin):
    uri: Optional[str] = None
    id: Optional[str] = None
    """ Internal identifier of a role """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemRegionalSettingsHomeCountry(DataClassJsonMixin):
    """ Extension country information """
    
    id: Optional[str] = None
    """ Internal identifier of a home country """
    
    uri: Optional[str] = None
    """ Canonical URI of a home country """
    
    name: Optional[str] = None
    """ Official name of a home country """
    
    iso_code: Optional[str] = None
    """ ISO code of a country """
    
    calling_code: Optional[str] = None
    """ Calling code of a country """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemRegionalSettingsTimezone(DataClassJsonMixin):
    """ Extension timezone information """
    
    id: Optional[str] = None
    """ Internal identifier of a timezone """
    
    uri: Optional[str] = None
    """ Canonical URI of a timezone """
    
    name: Optional[str] = None
    """ Short name of a timezone """
    
    description: Optional[str] = None
    """ Meaningful description of the timezone """
    
    bias: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemRegionalSettingsLanguage(DataClassJsonMixin):
    """ User interface language data """
    
    id: Optional[str] = None
    """ Internal identifier of a language """
    
    uri: Optional[str] = None
    """ Canonical URI of a language """
    
    greeting: Optional[bool] = None
    """ Indicates whether a language is available as greeting language """
    
    formatting_locale: Optional[bool] = None
    """ Indicates whether a language is available as formatting locale """
    
    locale_code: Optional[str] = None
    """ Localization code of a language """
    
    iso_code: Optional[str] = None
    """
    Country code according to the ISO standard, see [ISO
    3166](https://www.iso.org/iso-3166-country-codes.html)
    """
    
    name: Optional[str] = None
    """ Official name of a language """
    
    ui: Optional[bool] = None
    """ Indicates whether a language is available as UI language """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemRegionalSettingsGreetingLanguage(DataClassJsonMixin):
    """ Information on language used for telephony greetings """
    
    id: Optional[str] = None
    """ Internal identifier of a greeting language """
    
    locale_code: Optional[str] = None
    """ Localization code of a greeting language """
    
    name: Optional[str] = None
    """ Official name of a greeting language """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemRegionalSettingsFormattingLocale(DataClassJsonMixin):
    """ Formatting language preferences for numbers, dates and currencies """
    
    id: Optional[str] = None
    """ Internal identifier of a formatting language """
    
    locale_code: Optional[str] = None
    """ Localization code of a formatting language """
    
    name: Optional[str] = None

class ListExtensionsResponseRecordsItemRegionalSettingsTimeFormat(Enum):
    """ Time format setting. The default value is '12h' = ['12h', '24h'] """
    
    OBJECT_12h = '12h'
    OBJECT_24h = '24h'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemRegionalSettings(DataClassJsonMixin):
    """ Extension region data (timezone, home country, language) """
    
    home_country: Optional[ListExtensionsResponseRecordsItemRegionalSettingsHomeCountry] = None
    """ Extension country information """
    
    timezone: Optional[ListExtensionsResponseRecordsItemRegionalSettingsTimezone] = None
    """ Extension timezone information """
    
    language: Optional[ListExtensionsResponseRecordsItemRegionalSettingsLanguage] = None
    """ User interface language data """
    
    greeting_language: Optional[ListExtensionsResponseRecordsItemRegionalSettingsGreetingLanguage] = None
    """ Information on language used for telephony greetings """
    
    formatting_locale: Optional[ListExtensionsResponseRecordsItemRegionalSettingsFormattingLocale] = None
    """ Formatting language preferences for numbers, dates and currencies """
    
    time_format: Optional[ListExtensionsResponseRecordsItemRegionalSettingsTimeFormat] = None
    """ Time format setting. The default value is '12h' = ['12h', '24h'] """
    

class ListExtensionsResponseRecordsItemServiceFeaturesItemFeatureName(Enum):
    """ Feature name """
    
    AccountFederation = 'AccountFederation'
    Archiver = 'Archiver'
    AutomaticCallRecordingMute = 'AutomaticCallRecordingMute'
    AutomaticInboundCallRecording = 'AutomaticInboundCallRecording'
    AutomaticOutboundCallRecording = 'AutomaticOutboundCallRecording'
    BlockedMessageForwarding = 'BlockedMessageForwarding'
    Calendar = 'Calendar'
    CallerIdControl = 'CallerIdControl'
    CallForwarding = 'CallForwarding'
    CallPark = 'CallPark'
    CallParkLocations = 'CallParkLocations'
    CallSupervision = 'CallSupervision'
    CallSwitch = 'CallSwitch'
    CallQualitySurvey = 'CallQualitySurvey'
    Conferencing = 'Conferencing'
    ConferencingNumber = 'ConferencingNumber'
    ConfigureDelegates = 'ConfigureDelegates'
    DeveloperPortal = 'DeveloperPortal'
    DND = 'DND'
    DynamicConference = 'DynamicConference'
    EmergencyAddressAutoUpdate = 'EmergencyAddressAutoUpdate'
    EmergencyCalling = 'EmergencyCalling'
    EncryptionAtRest = 'EncryptionAtRest'
    ExternalDirectoryIntegration = 'ExternalDirectoryIntegration'
    Fax = 'Fax'
    FaxReceiving = 'FaxReceiving'
    FreeSoftPhoneLines = 'FreeSoftPhoneLines'
    HDVoice = 'HDVoice'
    HipaaCompliance = 'HipaaCompliance'
    Intercom = 'Intercom'
    InternationalCalling = 'InternationalCalling'
    InternationalSMS = 'InternationalSMS'
    LinkedSoftphoneLines = 'LinkedSoftphoneLines'
    MMS = 'MMS'
    MobileVoipEmergencyCalling = 'MobileVoipEmergencyCalling'
    OnDemandCallRecording = 'OnDemandCallRecording'
    Pager = 'Pager'
    PagerReceiving = 'PagerReceiving'
    Paging = 'Paging'
    PasswordAuth = 'PasswordAuth'
    PromoMessage = 'PromoMessage'
    Reports = 'Reports'
    Presence = 'Presence'
    RCTeams = 'RCTeams'
    RingOut = 'RingOut'
    SalesForce = 'SalesForce'
    SharedLines = 'SharedLines'
    SingleExtensionUI = 'SingleExtensionUI'
    SiteCodes = 'SiteCodes'
    SMS = 'SMS'
    SMSReceiving = 'SMSReceiving'
    SoftPhoneUpdate = 'SoftPhoneUpdate'
    TelephonySessions = 'TelephonySessions'
    UserManagement = 'UserManagement'
    VideoConferencing = 'VideoConferencing'
    VoipCalling = 'VoipCalling'
    VoipCallingOnMobile = 'VoipCallingOnMobile'
    Voicemail = 'Voicemail'
    VoicemailToText = 'VoicemailToText'
    WebPhone = 'WebPhone'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemServiceFeaturesItem(DataClassJsonMixin):
    enabled: Optional[bool] = None
    """ Feature status; shows feature availability for an extension """
    
    feature_name: Optional[ListExtensionsResponseRecordsItemServiceFeaturesItemFeatureName] = None
    """ Feature name """
    
    reason: Optional[str] = None
    """
    Reason for limitation of a particular service feature. Returned only if the enabled parameter
    value is 'False', see Service Feature Limitations and Reasons. When retrieving service features
    for an extension, the reasons for the limitations, if any, are returned in response
    """
    

class ListExtensionsResponseRecordsItemSetupWizardState(Enum):
    """ Specifies extension configuration wizard state (web service setup). """
    
    NotStarted = 'NotStarted'
    Incomplete = 'Incomplete'
    Completed = 'Completed'

class ListExtensionsResponseRecordsItemStatus(Enum):
    """
    Extension current state. If 'Unassigned' is specified, then extensions without
    ‘extensionNumber’ are returned. If not specified, then all extensions are returned
    
    Generated by Python OpenAPI Parser
    """
    
    Enabled = 'Enabled'
    Disabled = 'Disabled'
    Frozen = 'Frozen'
    NotActivated = 'NotActivated'
    Unassigned = 'Unassigned'

class ListExtensionsResponseRecordsItemStatusInfoReason(Enum):
    """ Type of suspension """
    
    Voluntarily = 'Voluntarily'
    Involuntarily = 'Involuntarily'
    SuspendedVoluntarily = 'SuspendedVoluntarily'
    SuspendedVoluntarily2 = 'SuspendedVoluntarily2'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemStatusInfo(DataClassJsonMixin):
    """ Status information (reason, comment). Returned for 'Disabled' status only """
    
    comment: Optional[str] = None
    """ A free-form user comment, describing the status change reason """
    
    reason: Optional[ListExtensionsResponseRecordsItemStatusInfoReason] = None
    """ Type of suspension """
    

class ListExtensionsResponseRecordsItemType(Enum):
    """ Extension type """
    
    User = 'User'
    FaxUser = 'FaxUser'
    VirtualUser = 'VirtualUser'
    DigitalUser = 'DigitalUser'
    Department = 'Department'
    Announcement = 'Announcement'
    Voicemail = 'Voicemail'
    SharedLinesGroup = 'SharedLinesGroup'
    PagingOnly = 'PagingOnly'
    IvrMenu = 'IvrMenu'
    ApplicationExtension = 'ApplicationExtension'
    ParkLocation = 'ParkLocation'
    Bot = 'Bot'
    Room = 'Room'
    Limited = 'Limited'
    Site = 'Site'
    ProxyAdmin = 'ProxyAdmin'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemCallQueueInfo(DataClassJsonMixin):
    """ For Department extension type only. Call queue settings """
    
    sla_goal: Optional[int] = None
    """
    Target percentage of calls that must be answered by agents within the service level time
    threshold
    """
    
    sla_threshold_seconds: Optional[int] = None
    """ Period of time in seconds that is considered to be an acceptable service level """
    
    include_abandoned_calls: Optional[bool] = None
    """
    If 'True' abandoned calls (hanged up prior to being served) are included into service level
    calculation
    """
    
    abandoned_threshold_seconds: Optional[int] = None
    """
    Period of time in seconds specifying abandoned calls duration - calls that are shorter will not
    be included into the calculation of service level.; zero value means that abandoned calls of
    any duration will be included into calculation
    """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItemSite(DataClassJsonMixin):
    """
    Site data. If multi-site feature is turned on for the account, then internal identifier of a
    site must be specified. To assign the wireless point to the main site (company) set site ID to
    `main-site`
    
    Generated by Python OpenAPI Parser
    """
    
    id: Optional[str] = None
    """ Internal identifier of a site """
    
    uri: Optional[str] = None
    """ Link to a site resource """
    
    name: Optional[str] = None
    """ Name of a site """
    
    code: Optional[str] = None
    """ Site code value. Returned only if specified """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseRecordsItem(DataClassJsonMixin):
    id: Optional[int] = None
    """ Internal identifier of an extension """
    
    uri: Optional[str] = None
    """ Canonical URI of an extension """
    
    account: Optional[ListExtensionsResponseRecordsItemAccount] = None
    """ Account information """
    
    contact: Optional[ListExtensionsResponseRecordsItemContact] = None
    """ Contact detailed information """
    
    custom_fields: Optional[List[ListExtensionsResponseRecordsItemCustomFieldsItem]] = None
    departments: Optional[List[ListExtensionsResponseRecordsItemDepartmentsItem]] = None
    """
    Information on department extension(s), to which the requested extension belongs. Returned only
    for user extensions, members of department, requested by single extensionId
    """
    
    extension_number: Optional[str] = None
    """ Number of department extension """
    
    extension_numbers: Optional[List[str]] = None
    name: Optional[str] = None
    """
    Extension name. For user extension types the value is a combination of the specified first name
    and last name
    """
    
    partner_id: Optional[str] = None
    """
    For Partner Applications Internal identifier of an extension created by partner. The
    RingCentral supports the mapping of accounts and stores the corresponding account ID/extension
    ID for each partner ID of a client application. In request URIs partner IDs are accepted
    instead of regular RingCentral native IDs as path parameters using pid = XXX clause. Though in
    response URIs contain the corresponding account IDs and extension IDs. In all request and
    response bodies these values are reflected via partnerId attributes of account and extension
    """
    
    permissions: Optional[ListExtensionsResponseRecordsItemPermissions] = None
    """
    Extension permissions, corresponding to the Service Web permissions 'Admin' and
    'InternationalCalling'
    """
    
    profile_image: Optional[ListExtensionsResponseRecordsItemProfileImage] = None
    """ Information on profile image """
    
    references: Optional[List[ListExtensionsResponseRecordsItemReferencesItem]] = None
    """ List of non-RC internal identifiers assigned to an extension """
    
    roles: Optional[List[ListExtensionsResponseRecordsItemRolesItem]] = None
    regional_settings: Optional[ListExtensionsResponseRecordsItemRegionalSettings] = None
    """ Extension region data (timezone, home country, language) """
    
    service_features: Optional[List[ListExtensionsResponseRecordsItemServiceFeaturesItem]] = None
    """
    Extension service features returned in response only when the logged-in user requests his/her
    own extension info, see also Extension Service Features
    """
    
    setup_wizard_state: Optional[ListExtensionsResponseRecordsItemSetupWizardState] = 'NotStarted'
    """ Specifies extension configuration wizard state (web service setup). """
    
    status: Optional[ListExtensionsResponseRecordsItemStatus] = None
    """
    Extension current state. If 'Unassigned' is specified, then extensions without
    ‘extensionNumber’ are returned. If not specified, then all extensions are returned
    """
    
    status_info: Optional[ListExtensionsResponseRecordsItemStatusInfo] = None
    """ Status information (reason, comment). Returned for 'Disabled' status only """
    
    type: Optional[ListExtensionsResponseRecordsItemType] = None
    """ Extension type """
    
    call_queue_info: Optional[ListExtensionsResponseRecordsItemCallQueueInfo] = None
    """ For Department extension type only. Call queue settings """
    
    hidden: Optional[bool] = None
    """ Hides extension from showing in company directory. Supported for extensions of User type only """
    
    site: Optional[ListExtensionsResponseRecordsItemSite] = None
    """
    Site data. If multi-site feature is turned on for the account, then internal identifier of a
    site must be specified. To assign the wireless point to the main site (company) set site ID to
    `main-site`
    """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseNavigationFirstPage(DataClassJsonMixin):
    """ Canonical URI for the first page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseNavigationNextPage(DataClassJsonMixin):
    """ Canonical URI for the next page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseNavigationPreviousPage(DataClassJsonMixin):
    """ Canonical URI for the previous page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseNavigationLastPage(DataClassJsonMixin):
    """ Canonical URI for the last page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponseNavigation(DataClassJsonMixin):
    """ Information on navigation """
    
    first_page: Optional[ListExtensionsResponseNavigationFirstPage] = None
    """ Canonical URI for the first page of the list """
    
    next_page: Optional[ListExtensionsResponseNavigationNextPage] = None
    """ Canonical URI for the next page of the list """
    
    previous_page: Optional[ListExtensionsResponseNavigationPreviousPage] = None
    """ Canonical URI for the previous page of the list """
    
    last_page: Optional[ListExtensionsResponseNavigationLastPage] = None
    """ Canonical URI for the last page of the list """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponsePaging(DataClassJsonMixin):
    """ Information on paging """
    
    page: Optional[int] = None
    """
    The current page number. 1-indexed, so the first page is 1 by default. May be omitted if result
    is empty (because non-existent page was specified or perPage=0 was requested)
    """
    
    per_page: Optional[int] = None
    """
    Current page size, describes how many items are in each page. Default value is 100. Maximum
    value is 1000. If perPage value in the request is greater than 1000, the maximum value (1000)
    is applied
    """
    
    page_start: Optional[int] = None
    """
    The zero-based number of the first element on the current page. Omitted if the page is omitted
    or result is empty
    """
    
    page_end: Optional[int] = None
    """
    The zero-based index of the last element on the current page. Omitted if the page is omitted or
    result is empty
    """
    
    total_pages: Optional[int] = None
    """
    The total number of pages in a dataset. May be omitted for some resources due to performance
    reasons
    """
    
    total_elements: Optional[int] = None
    """
    The total number of elements in a dataset. May be omitted for some resource due to performance
    reasons
    """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListExtensionsResponse(DataClassJsonMixin):
    """
    Required Properties:
     - records
    
    Generated by Python OpenAPI Parser
    """
    
    records: List[ListExtensionsResponseRecordsItem]
    """ List of extensions with extension information """
    
    uri: Optional[str] = None
    """ Link to the extension list resource """
    
    navigation: Optional[ListExtensionsResponseNavigation] = None
    """ Information on navigation """
    
    paging: Optional[ListExtensionsResponsePaging] = None
    """ Information on paging """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequestContactBusinessAddress(DataClassJsonMixin):
    country: Optional[str] = None
    """ Country name of an extension user company """
    
    state: Optional[str] = None
    """ State/province name of an extension user company. Mandatory for the USA, UK and Canada """
    
    city: Optional[str] = None
    """ City name of an extension user company """
    
    street: Optional[str] = None
    """ Street address of an extension user company """
    
    zip: Optional[str] = None
    """ Zip code of an extension user company """
    

class CreateExtensionRequestContactPronouncedNameType(Enum):
    """
    Voice name type. 'Default' - default extension name; first name and last name specified in user
    profile; 'TextToSpeech' - custom text; user name spelled the way it sounds and specified by
    user; 'Recorded' - custom audio, user name recorded in user's own voice (supported only for
    extension retrieval)
    
    Generated by Python OpenAPI Parser
    """
    
    Default = 'Default'
    TextToSpeech = 'TextToSpeech'
    Recorded = 'Recorded'

class CreateExtensionRequestContactPronouncedNamePromptContentType(Enum):
    """ Content media type """
    
    AudioMpeg = 'audio/mpeg'
    AudioWav = 'audio/wav'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequestContactPronouncedNamePrompt(DataClassJsonMixin):
    id: Optional[str] = None
    content_uri: Optional[str] = None
    """ Link to a prompt resource """
    
    content_type: Optional[CreateExtensionRequestContactPronouncedNamePromptContentType] = None
    """ Content media type """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequestContactPronouncedName(DataClassJsonMixin):
    type: Optional[CreateExtensionRequestContactPronouncedNameType] = None
    """
    Voice name type. 'Default' - default extension name; first name and last name specified in user
    profile; 'TextToSpeech' - custom text; user name spelled the way it sounds and specified by
    user; 'Recorded' - custom audio, user name recorded in user's own voice (supported only for
    extension retrieval)
    """
    
    text: Optional[str] = None
    """ Custom text """
    
    prompt: Optional[CreateExtensionRequestContactPronouncedNamePrompt] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequestContact(DataClassJsonMixin):
    """ Contact Information """
    
    first_name: Optional[str] = None
    """ For User extension type only. Extension user first name """
    
    last_name: Optional[str] = None
    """ For User extension type only. Extension user last name """
    
    company: Optional[str] = None
    """ Extension user company name """
    
    job_title: Optional[str] = None
    email: Optional[str] = None
    """ Email of extension user """
    
    business_phone: Optional[str] = None
    """
    Extension user contact phone number in [E.164](https://www.itu.int/rec/T-REC-E.164-201011-I)
    format
    """
    
    mobile_phone: Optional[str] = None
    """
    Extension user mobile (**non** Toll Free) phone number in
    [E.164](https://www.itu.int/rec/T-REC-E.164-201011-I) (with '+' sign) format
    """
    
    business_address: Optional[CreateExtensionRequestContactBusinessAddress] = None
    email_as_login_name: Optional[bool] = None
    """
    If 'True' then contact email is enabled as login name for this user. Please note that email
    should be unique in this case. The default value is 'False'
    """
    
    pronounced_name: Optional[CreateExtensionRequestContactPronouncedName] = None
    department: Optional[str] = None
    """ Extension user department, if any """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequestCustomFieldsItem(DataClassJsonMixin):
    id: Optional[str] = None
    """ Internal identifier of a custom field """
    
    value: Optional[str] = None
    """ Custom field value """
    
    display_name: Optional[str] = None

class CreateExtensionRequestReferencesItemType(Enum):
    """ Type of external identifier """
    
    PartnerId = 'PartnerId'
    CustomerDirectoryId = 'CustomerDirectoryId'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequestReferencesItem(DataClassJsonMixin):
    ref: Optional[str] = None
    """ Non-RC identifier of an extension """
    
    type: Optional[CreateExtensionRequestReferencesItemType] = None
    """ Type of external identifier """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequestRegionalSettingsHomeCountry(DataClassJsonMixin):
    """ Extension country information """
    
    id: Optional[str] = None
    """ Internal identifier of a home country """
    
    uri: Optional[str] = None
    """ Canonical URI of a home country """
    
    name: Optional[str] = None
    """ Official name of a home country """
    
    iso_code: Optional[str] = None
    """ ISO code of a country """
    
    calling_code: Optional[str] = None
    """ Calling code of a country """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequestRegionalSettingsTimezone(DataClassJsonMixin):
    """ Extension timezone information """
    
    id: Optional[str] = None
    """ Internal identifier of a timezone """
    
    uri: Optional[str] = None
    """ Canonical URI of a timezone """
    
    name: Optional[str] = None
    """ Short name of a timezone """
    
    description: Optional[str] = None
    """ Meaningful description of the timezone """
    
    bias: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequestRegionalSettingsLanguage(DataClassJsonMixin):
    """ User interface language data """
    
    id: Optional[str] = None
    """ Internal identifier of a language """
    
    uri: Optional[str] = None
    """ Canonical URI of a language """
    
    greeting: Optional[bool] = None
    """ Indicates whether a language is available as greeting language """
    
    formatting_locale: Optional[bool] = None
    """ Indicates whether a language is available as formatting locale """
    
    locale_code: Optional[str] = None
    """ Localization code of a language """
    
    iso_code: Optional[str] = None
    """
    Country code according to the ISO standard, see [ISO
    3166](https://www.iso.org/iso-3166-country-codes.html)
    """
    
    name: Optional[str] = None
    """ Official name of a language """
    
    ui: Optional[bool] = None
    """ Indicates whether a language is available as UI language """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequestRegionalSettingsGreetingLanguage(DataClassJsonMixin):
    """ Information on language used for telephony greetings """
    
    id: Optional[str] = None
    """ Internal identifier of a greeting language """
    
    locale_code: Optional[str] = None
    """ Localization code of a greeting language """
    
    name: Optional[str] = None
    """ Official name of a greeting language """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequestRegionalSettingsFormattingLocale(DataClassJsonMixin):
    """ Formatting language preferences for numbers, dates and currencies """
    
    id: Optional[str] = None
    """ Internal identifier of a formatting language """
    
    locale_code: Optional[str] = None
    """ Localization code of a formatting language """
    
    name: Optional[str] = None

class CreateExtensionRequestRegionalSettingsTimeFormat(Enum):
    """ Time format setting. The default value is '12h' = ['12h', '24h'] """
    
    OBJECT_12h = '12h'
    OBJECT_24h = '24h'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequestRegionalSettings(DataClassJsonMixin):
    """ Extension region data (timezone, home country, language) """
    
    home_country: Optional[CreateExtensionRequestRegionalSettingsHomeCountry] = None
    """ Extension country information """
    
    timezone: Optional[CreateExtensionRequestRegionalSettingsTimezone] = None
    """ Extension timezone information """
    
    language: Optional[CreateExtensionRequestRegionalSettingsLanguage] = None
    """ User interface language data """
    
    greeting_language: Optional[CreateExtensionRequestRegionalSettingsGreetingLanguage] = None
    """ Information on language used for telephony greetings """
    
    formatting_locale: Optional[CreateExtensionRequestRegionalSettingsFormattingLocale] = None
    """ Formatting language preferences for numbers, dates and currencies """
    
    time_format: Optional[CreateExtensionRequestRegionalSettingsTimeFormat] = None
    """ Time format setting. The default value is '12h' = ['12h', '24h'] """
    

class CreateExtensionRequestSetupWizardState(Enum):
    """ Specifies extension configuration wizard state (web service setup). """
    
    NotStarted = 'NotStarted'
    Incomplete = 'Incomplete'
    Completed = 'Completed'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequestSiteBusinessAddress(DataClassJsonMixin):
    """ Extension user business address. The default is Company settings """
    
    country: Optional[str] = None
    """ Country name of an extension user company """
    
    state: Optional[str] = None
    """ State/province name of an extension user company. Mandatory for the USA, UK and Canada """
    
    city: Optional[str] = None
    """ City name of an extension user company """
    
    street: Optional[str] = None
    """ Street address of an extension user company """
    
    zip: Optional[str] = None
    """ Zip code of an extension user company """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequestSiteRegionalSettingsHomeCountry(DataClassJsonMixin):
    """ Extension country information """
    
    id: Optional[str] = None
    """ Internal identifier of a home country """
    
    uri: Optional[str] = None
    """ Canonical URI of a home country """
    
    name: Optional[str] = None
    """ Official name of a home country """
    
    iso_code: Optional[str] = None
    """ ISO code of a country """
    
    calling_code: Optional[str] = None
    """ Calling code of a country """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequestSiteRegionalSettingsTimezone(DataClassJsonMixin):
    """ Extension timezone information """
    
    id: Optional[str] = None
    """ Internal identifier of a timezone """
    
    uri: Optional[str] = None
    """ Canonical URI of a timezone """
    
    name: Optional[str] = None
    """ Short name of a timezone """
    
    description: Optional[str] = None
    """ Meaningful description of the timezone """
    
    bias: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequestSiteRegionalSettingsLanguage(DataClassJsonMixin):
    """ User interface language data """
    
    id: Optional[str] = None
    """ Internal identifier of a language """
    
    uri: Optional[str] = None
    """ Canonical URI of a language """
    
    greeting: Optional[bool] = None
    """ Indicates whether a language is available as greeting language """
    
    formatting_locale: Optional[bool] = None
    """ Indicates whether a language is available as formatting locale """
    
    locale_code: Optional[str] = None
    """ Localization code of a language """
    
    iso_code: Optional[str] = None
    """
    Country code according to the ISO standard, see [ISO
    3166](https://www.iso.org/iso-3166-country-codes.html)
    """
    
    name: Optional[str] = None
    """ Official name of a language """
    
    ui: Optional[bool] = None
    """ Indicates whether a language is available as UI language """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequestSiteRegionalSettingsGreetingLanguage(DataClassJsonMixin):
    """ Information on language used for telephony greetings """
    
    id: Optional[str] = None
    """ Internal identifier of a greeting language """
    
    locale_code: Optional[str] = None
    """ Localization code of a greeting language """
    
    name: Optional[str] = None
    """ Official name of a greeting language """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequestSiteRegionalSettingsFormattingLocale(DataClassJsonMixin):
    """ Formatting language preferences for numbers, dates and currencies """
    
    id: Optional[str] = None
    """ Internal identifier of a formatting language """
    
    locale_code: Optional[str] = None
    """ Localization code of a formatting language """
    
    name: Optional[str] = None

class CreateExtensionRequestSiteRegionalSettingsTimeFormat(Enum):
    """ Time format setting. The default value is '12h' = ['12h', '24h'] """
    
    OBJECT_12h = '12h'
    OBJECT_24h = '24h'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequestSiteRegionalSettings(DataClassJsonMixin):
    """ Information about regional settings. The default is Company settings """
    
    home_country: Optional[CreateExtensionRequestSiteRegionalSettingsHomeCountry] = None
    """ Extension country information """
    
    timezone: Optional[CreateExtensionRequestSiteRegionalSettingsTimezone] = None
    """ Extension timezone information """
    
    language: Optional[CreateExtensionRequestSiteRegionalSettingsLanguage] = None
    """ User interface language data """
    
    greeting_language: Optional[CreateExtensionRequestSiteRegionalSettingsGreetingLanguage] = None
    """ Information on language used for telephony greetings """
    
    formatting_locale: Optional[CreateExtensionRequestSiteRegionalSettingsFormattingLocale] = None
    """ Formatting language preferences for numbers, dates and currencies """
    
    time_format: Optional[CreateExtensionRequestSiteRegionalSettingsTimeFormat] = None
    """ Time format setting. The default value is '12h' = ['12h', '24h'] """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequestSiteOperator(DataClassJsonMixin):
    """ Site Fax/SMS recipient (operator) reference. Multi-level IVR should be enabled """
    
    id: Optional[str] = None
    """ Internal identifier of an operator """
    
    uri: Optional[str] = None
    """ Link to an operator resource """
    
    extension_number: Optional[str] = None
    """ Extension number (pin) """
    
    name: Optional[str] = None
    """ Operator extension user full name """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequestSite(DataClassJsonMixin):
    id: Optional[str] = None
    """ Internal idetifier of a site extension """
    
    uri: Optional[str] = None
    """ Link to a site resource """
    
    name: Optional[str] = None
    """ Extension user first name """
    
    extension_number: Optional[str] = None
    """ Extension number """
    
    caller_id_name: Optional[str] = None
    """
    Custom name of a caller. Max number of characters is 15 (only alphabetical symbols, numbers and
    commas are supported)
    """
    
    email: Optional[str] = None
    """ Exetnsion user email """
    
    business_address: Optional[CreateExtensionRequestSiteBusinessAddress] = None
    """ Extension user business address. The default is Company settings """
    
    regional_settings: Optional[CreateExtensionRequestSiteRegionalSettings] = None
    """ Information about regional settings. The default is Company settings """
    
    operator: Optional[CreateExtensionRequestSiteOperator] = None
    """ Site Fax/SMS recipient (operator) reference. Multi-level IVR should be enabled """
    
    code: Optional[str] = None
    """ Site code value. Returned only if specified """
    

class CreateExtensionRequestStatus(Enum):
    """ Extension current state """
    
    Enabled = 'Enabled'
    Disabled = 'Disabled'
    NotActivated = 'NotActivated'
    Unassigned = 'Unassigned'
    Frozen = 'Frozen'

class CreateExtensionRequestStatusInfoReason(Enum):
    """ Type of suspension """
    
    Voluntarily = 'Voluntarily'
    Involuntarily = 'Involuntarily'
    SuspendedVoluntarily = 'SuspendedVoluntarily'
    SuspendedVoluntarily2 = 'SuspendedVoluntarily2'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequestStatusInfo(DataClassJsonMixin):
    """ Status information (reason, comment). For 'Disabled' status only """
    
    comment: Optional[str] = None
    """ A free-form user comment, describing the status change reason """
    
    reason: Optional[CreateExtensionRequestStatusInfoReason] = None
    """ Type of suspension """
    

class CreateExtensionRequestType(Enum):
    """ Extension type """
    
    User = 'User'
    VirtualUser = 'VirtualUser'
    DigitalUser = 'DigitalUser'
    Department = 'Department'
    Announcement = 'Announcement'
    Voicemail = 'Voicemail'
    SharedLinesGroup = 'SharedLinesGroup'
    PagingOnly = 'PagingOnly'
    ParkLocation = 'ParkLocation'
    Limited = 'Limited'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionRequest(DataClassJsonMixin):
    contact: Optional[CreateExtensionRequestContact] = None
    """ Contact Information """
    
    extension_number: Optional[str] = None
    """ Number of extension """
    
    custom_fields: Optional[List[CreateExtensionRequestCustomFieldsItem]] = None
    password: Optional[str] = None
    """ Password for extension. If not specified, the password is auto-generated """
    
    references: Optional[List[CreateExtensionRequestReferencesItem]] = None
    """ List of non-RC internal identifiers assigned to an extension """
    
    regional_settings: Optional[CreateExtensionRequestRegionalSettings] = None
    """ Extension region data (timezone, home country, language) """
    
    partner_id: Optional[str] = None
    """ Additional extension identifier, created by partner application and applied on client side """
    
    ivr_pin: Optional[str] = None
    """ IVR PIN """
    
    setup_wizard_state: Optional[CreateExtensionRequestSetupWizardState] = 'NotStarted'
    """ Specifies extension configuration wizard state (web service setup). """
    
    site: Optional[CreateExtensionRequestSite] = None
    status: Optional[CreateExtensionRequestStatus] = None
    """ Extension current state """
    
    status_info: Optional[CreateExtensionRequestStatusInfo] = None
    """ Status information (reason, comment). For 'Disabled' status only """
    
    type: Optional[CreateExtensionRequestType] = None
    """ Extension type """
    
    hidden: Optional[bool] = None
    """
    Hides extension from showing in company directory. Supported for extensions of User type only.
    For unassigned extensions the value is set to 'True' by default. For assigned extensions the
    value is set to 'False' by default
    """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionResponseContactBusinessAddress(DataClassJsonMixin):
    """ Business address of extension user company """
    
    country: Optional[str] = None
    """ Country name of an extension user company """
    
    state: Optional[str] = None
    """ State/province name of an extension user company. Mandatory for the USA, UK and Canada """
    
    city: Optional[str] = None
    """ City name of an extension user company """
    
    street: Optional[str] = None
    """ Street address of an extension user company """
    
    zip: Optional[str] = None
    """ Zip code of an extension user company """
    

class CreateExtensionResponseContactPronouncedNameType(Enum):
    """
    Voice name type. 'Default' - default extension name; first name and last name specified in user
    profile; 'TextToSpeech' - custom text; user name spelled the way it sounds and specified by
    user; 'Recorded' - custom audio, user name recorded in user's own voice (supported only for
    extension retrieval)
    
    Generated by Python OpenAPI Parser
    """
    
    Default = 'Default'
    TextToSpeech = 'TextToSpeech'
    Recorded = 'Recorded'

class CreateExtensionResponseContactPronouncedNamePromptContentType(Enum):
    """ Content media type """
    
    AudioMpeg = 'audio/mpeg'
    AudioWav = 'audio/wav'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionResponseContactPronouncedNamePrompt(DataClassJsonMixin):
    id: Optional[str] = None
    content_uri: Optional[str] = None
    """ Link to a prompt resource """
    
    content_type: Optional[CreateExtensionResponseContactPronouncedNamePromptContentType] = None
    """ Content media type """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionResponseContactPronouncedName(DataClassJsonMixin):
    type: Optional[CreateExtensionResponseContactPronouncedNameType] = None
    """
    Voice name type. 'Default' - default extension name; first name and last name specified in user
    profile; 'TextToSpeech' - custom text; user name spelled the way it sounds and specified by
    user; 'Recorded' - custom audio, user name recorded in user's own voice (supported only for
    extension retrieval)
    """
    
    text: Optional[str] = None
    """ Custom text """
    
    prompt: Optional[CreateExtensionResponseContactPronouncedNamePrompt] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionResponseContact(DataClassJsonMixin):
    """ Contact detailed information """
    
    first_name: Optional[str] = None
    """ For User extension type only. Extension user first name """
    
    last_name: Optional[str] = None
    """ For User extension type only. Extension user last name """
    
    company: Optional[str] = None
    """ Extension user company name """
    
    job_title: Optional[str] = None
    email: Optional[str] = None
    """ Email of extension user """
    
    business_phone: Optional[str] = None
    """
    Extension user contact phone number in [E.164](https://www.itu.int/rec/T-REC-E.164-201011-I)
    (with '+' sign) format
    """
    
    mobile_phone: Optional[str] = None
    """
    Extension user mobile (**non** Toll Free) phone number in
    [E.164](https://www.itu.int/rec/T-REC-E.164-201011-I) (with '+' sign) format
    """
    
    business_address: Optional[CreateExtensionResponseContactBusinessAddress] = None
    """ Business address of extension user company """
    
    email_as_login_name: Optional[bool] = 'False'
    """
    If 'True' then contact email is enabled as login name for this user. Please note that email
    should be unique in this case.
    """
    
    pronounced_name: Optional[CreateExtensionResponseContactPronouncedName] = None
    department: Optional[str] = None
    """ Extension user department, if any """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionResponseCustomFieldsItem(DataClassJsonMixin):
    id: Optional[str] = None
    """ Internal identifier of a custom field """
    
    value: Optional[str] = None
    """ Custom field value """
    
    display_name: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionResponsePermissionsAdmin(DataClassJsonMixin):
    """ Admin permission """
    
    enabled: Optional[bool] = None
    """ Specifies if a permission is enabled or not """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionResponsePermissionsInternationalCalling(DataClassJsonMixin):
    """ International Calling permission """
    
    enabled: Optional[bool] = None
    """ Specifies if a permission is enabled or not """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionResponsePermissions(DataClassJsonMixin):
    """
    Extension permissions, corresponding to the Service Web permissions 'Admin' and
    'InternationalCalling'
    
    Generated by Python OpenAPI Parser
    """
    
    admin: Optional[CreateExtensionResponsePermissionsAdmin] = None
    """ Admin permission """
    
    international_calling: Optional[CreateExtensionResponsePermissionsInternationalCalling] = None
    """ International Calling permission """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionResponseProfileImageScalesItem(DataClassJsonMixin):
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionResponseProfileImage(DataClassJsonMixin):
    """
    Information on profile image
    
    Required Properties:
     - uri
    
    Generated by Python OpenAPI Parser
    """
    
    uri: str
    """ Link to a profile image. If an image is not uploaded for an extension, only uri is returned """
    
    etag: Optional[str] = None
    """ Identifier of an image """
    
    last_modified: Optional[datetime] = field(metadata=config(encoder=datetime.isoformat, decoder=datetime_decoder(datetime)), default=None)
    """
    The datetime when an image was last updated in ISO 8601 format, for example
    2016-03-10T18:07:52.534Z
    """
    
    content_type: Optional[str] = None
    """ The type of an image """
    
    scales: Optional[List[CreateExtensionResponseProfileImageScalesItem]] = None
    """ List of URIs to profile images in different dimensions """
    

class CreateExtensionResponseReferencesItemType(Enum):
    """ Type of external identifier """
    
    PartnerId = 'PartnerId'
    CustomerDirectoryId = 'CustomerDirectoryId'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionResponseReferencesItem(DataClassJsonMixin):
    ref: Optional[str] = None
    """ Non-RC identifier of an extension """
    
    type: Optional[CreateExtensionResponseReferencesItemType] = None
    """ Type of external identifier """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionResponseRegionalSettingsHomeCountry(DataClassJsonMixin):
    """ Extension country information """
    
    id: Optional[str] = None
    """ Internal identifier of a home country """
    
    uri: Optional[str] = None
    """ Canonical URI of a home country """
    
    name: Optional[str] = None
    """ Official name of a home country """
    
    iso_code: Optional[str] = None
    """ ISO code of a country """
    
    calling_code: Optional[str] = None
    """ Calling code of a country """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionResponseRegionalSettingsTimezone(DataClassJsonMixin):
    """ Extension timezone information """
    
    id: Optional[str] = None
    """ Internal identifier of a timezone """
    
    uri: Optional[str] = None
    """ Canonical URI of a timezone """
    
    name: Optional[str] = None
    """ Short name of a timezone """
    
    description: Optional[str] = None
    """ Meaningful description of the timezone """
    
    bias: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionResponseRegionalSettingsLanguage(DataClassJsonMixin):
    """ User interface language data """
    
    id: Optional[str] = None
    """ Internal identifier of a language """
    
    uri: Optional[str] = None
    """ Canonical URI of a language """
    
    greeting: Optional[bool] = None
    """ Indicates whether a language is available as greeting language """
    
    formatting_locale: Optional[bool] = None
    """ Indicates whether a language is available as formatting locale """
    
    locale_code: Optional[str] = None
    """ Localization code of a language """
    
    iso_code: Optional[str] = None
    """
    Country code according to the ISO standard, see [ISO
    3166](https://www.iso.org/iso-3166-country-codes.html)
    """
    
    name: Optional[str] = None
    """ Official name of a language """
    
    ui: Optional[bool] = None
    """ Indicates whether a language is available as UI language """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionResponseRegionalSettingsGreetingLanguage(DataClassJsonMixin):
    """ Information on language used for telephony greetings """
    
    id: Optional[str] = None
    """ Internal identifier of a greeting language """
    
    locale_code: Optional[str] = None
    """ Localization code of a greeting language """
    
    name: Optional[str] = None
    """ Official name of a greeting language """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionResponseRegionalSettingsFormattingLocale(DataClassJsonMixin):
    """ Formatting language preferences for numbers, dates and currencies """
    
    id: Optional[str] = None
    """ Internal identifier of a formatting language """
    
    locale_code: Optional[str] = None
    """ Localization code of a formatting language """
    
    name: Optional[str] = None

class CreateExtensionResponseRegionalSettingsTimeFormat(Enum):
    """ Time format setting. The default value is '12h' = ['12h', '24h'] """
    
    OBJECT_12h = '12h'
    OBJECT_24h = '24h'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionResponseRegionalSettings(DataClassJsonMixin):
    """ Extension region data (timezone, home country, language) """
    
    home_country: Optional[CreateExtensionResponseRegionalSettingsHomeCountry] = None
    """ Extension country information """
    
    timezone: Optional[CreateExtensionResponseRegionalSettingsTimezone] = None
    """ Extension timezone information """
    
    language: Optional[CreateExtensionResponseRegionalSettingsLanguage] = None
    """ User interface language data """
    
    greeting_language: Optional[CreateExtensionResponseRegionalSettingsGreetingLanguage] = None
    """ Information on language used for telephony greetings """
    
    formatting_locale: Optional[CreateExtensionResponseRegionalSettingsFormattingLocale] = None
    """ Formatting language preferences for numbers, dates and currencies """
    
    time_format: Optional[CreateExtensionResponseRegionalSettingsTimeFormat] = None
    """ Time format setting. The default value is '12h' = ['12h', '24h'] """
    

class CreateExtensionResponseServiceFeaturesItemFeatureName(Enum):
    """ Feature name """
    
    AccountFederation = 'AccountFederation'
    Archiver = 'Archiver'
    AutomaticCallRecordingMute = 'AutomaticCallRecordingMute'
    AutomaticInboundCallRecording = 'AutomaticInboundCallRecording'
    AutomaticOutboundCallRecording = 'AutomaticOutboundCallRecording'
    BlockedMessageForwarding = 'BlockedMessageForwarding'
    Calendar = 'Calendar'
    CallerIdControl = 'CallerIdControl'
    CallForwarding = 'CallForwarding'
    CallPark = 'CallPark'
    CallParkLocations = 'CallParkLocations'
    CallSupervision = 'CallSupervision'
    CallSwitch = 'CallSwitch'
    CallQualitySurvey = 'CallQualitySurvey'
    Conferencing = 'Conferencing'
    ConferencingNumber = 'ConferencingNumber'
    ConfigureDelegates = 'ConfigureDelegates'
    DeveloperPortal = 'DeveloperPortal'
    DND = 'DND'
    DynamicConference = 'DynamicConference'
    EmergencyAddressAutoUpdate = 'EmergencyAddressAutoUpdate'
    EmergencyCalling = 'EmergencyCalling'
    EncryptionAtRest = 'EncryptionAtRest'
    ExternalDirectoryIntegration = 'ExternalDirectoryIntegration'
    Fax = 'Fax'
    FaxReceiving = 'FaxReceiving'
    FreeSoftPhoneLines = 'FreeSoftPhoneLines'
    HDVoice = 'HDVoice'
    HipaaCompliance = 'HipaaCompliance'
    Intercom = 'Intercom'
    InternationalCalling = 'InternationalCalling'
    InternationalSMS = 'InternationalSMS'
    LinkedSoftphoneLines = 'LinkedSoftphoneLines'
    MMS = 'MMS'
    MobileVoipEmergencyCalling = 'MobileVoipEmergencyCalling'
    OnDemandCallRecording = 'OnDemandCallRecording'
    Pager = 'Pager'
    PagerReceiving = 'PagerReceiving'
    Paging = 'Paging'
    PasswordAuth = 'PasswordAuth'
    PromoMessage = 'PromoMessage'
    Reports = 'Reports'
    Presence = 'Presence'
    RCTeams = 'RCTeams'
    RingOut = 'RingOut'
    SalesForce = 'SalesForce'
    SharedLines = 'SharedLines'
    SingleExtensionUI = 'SingleExtensionUI'
    SiteCodes = 'SiteCodes'
    SMS = 'SMS'
    SMSReceiving = 'SMSReceiving'
    SoftPhoneUpdate = 'SoftPhoneUpdate'
    TelephonySessions = 'TelephonySessions'
    UserManagement = 'UserManagement'
    VideoConferencing = 'VideoConferencing'
    VoipCalling = 'VoipCalling'
    VoipCallingOnMobile = 'VoipCallingOnMobile'
    Voicemail = 'Voicemail'
    VoicemailToText = 'VoicemailToText'
    WebPhone = 'WebPhone'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionResponseServiceFeaturesItem(DataClassJsonMixin):
    enabled: Optional[bool] = None
    """ Feature status; shows feature availability for an extension """
    
    feature_name: Optional[CreateExtensionResponseServiceFeaturesItemFeatureName] = None
    """ Feature name """
    
    reason: Optional[str] = None
    """
    Reason for limitation of a particular service feature. Returned only if the enabled parameter
    value is 'False', see Service Feature Limitations and Reasons. When retrieving service features
    for an extension, the reasons for the limitations, if any, are returned in response
    """
    

class CreateExtensionResponseSetupWizardState(Enum):
    """
    Specifies extension configuration wizard state (web service setup). The default value is
    'NotStarted'
    
    Generated by Python OpenAPI Parser
    """
    
    NotStarted = 'NotStarted'
    Incomplete = 'Incomplete'
    Completed = 'Completed'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionResponseSite(DataClassJsonMixin):
    """
    Site data. If multi-site feature is turned on for the account, then internal identifier of a
    site must be specified. To assign the wireless point to the main site (company) set site ID to
    `main-site`
    
    Generated by Python OpenAPI Parser
    """
    
    id: Optional[str] = None
    """ Internal identifier of a site """
    
    uri: Optional[str] = None
    """ Link to a site resource """
    
    name: Optional[str] = None
    """ Name of a site """
    
    code: Optional[str] = None
    """ Site code value. Returned only if specified """
    

class CreateExtensionResponseStatus(Enum):
    """
    Extension current state. If 'Unassigned' is specified, then extensions without
    ‘extensionNumber’ are returned. If not specified, then all extensions are returned
    
    Generated by Python OpenAPI Parser
    """
    
    Enabled = 'Enabled'
    Disabled = 'Disabled'
    Frozen = 'Frozen'
    NotActivated = 'NotActivated'
    Unassigned = 'Unassigned'

class CreateExtensionResponseStatusInfoReason(Enum):
    """ Type of suspension """
    
    Voluntarily = 'Voluntarily'
    Involuntarily = 'Involuntarily'
    SuspendedVoluntarily = 'SuspendedVoluntarily'
    SuspendedVoluntarily2 = 'SuspendedVoluntarily2'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionResponseStatusInfo(DataClassJsonMixin):
    """ Status information (reason, comment). Returned for 'Disabled' status only """
    
    comment: Optional[str] = None
    """ A free-form user comment, describing the status change reason """
    
    reason: Optional[CreateExtensionResponseStatusInfoReason] = None
    """ Type of suspension """
    

class CreateExtensionResponseType(Enum):
    """ Extension type """
    
    User = 'User'
    VirtualUser = 'VirtualUser'
    DigitalUser = 'DigitalUser'
    Department = 'Department'
    Announcement = 'Announcement'
    Voicemail = 'Voicemail'
    SharedLinesGroup = 'SharedLinesGroup'
    PagingOnly = 'PagingOnly'
    ParkLocation = 'ParkLocation'
    Limited = 'Limited'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class CreateExtensionResponse(DataClassJsonMixin):
    id: Optional[int] = None
    """ Internal identifier of an extension """
    
    uri: Optional[str] = None
    """ Canonical URI of an extension """
    
    contact: Optional[CreateExtensionResponseContact] = None
    """ Contact detailed information """
    
    custom_fields: Optional[List[CreateExtensionResponseCustomFieldsItem]] = None
    extension_number: Optional[str] = None
    """ Number of department extension """
    
    name: Optional[str] = None
    """
    Extension name. For user extension types the value is a combination of the specified first name
    and last name
    """
    
    partner_id: Optional[str] = None
    """
    For Partner Applications Internal identifier of an extension created by partner. The
    RingCentral supports the mapping of accounts and stores the corresponding account ID/extension
    ID for each partner ID of a client application. In request URIs partner IDs are accepted
    instead of regular RingCentral native IDs as path parameters using pid = XXX clause. Though in
    response URIs contain the corresponding account IDs and extension IDs. In all request and
    response bodies these values are reflected via partnerId attributes of account and extension
    """
    
    permissions: Optional[CreateExtensionResponsePermissions] = None
    """
    Extension permissions, corresponding to the Service Web permissions 'Admin' and
    'InternationalCalling'
    """
    
    profile_image: Optional[CreateExtensionResponseProfileImage] = None
    """ Information on profile image """
    
    references: Optional[List[CreateExtensionResponseReferencesItem]] = None
    """ List of non-RC internal identifiers assigned to an extension """
    
    regional_settings: Optional[CreateExtensionResponseRegionalSettings] = None
    """ Extension region data (timezone, home country, language) """
    
    service_features: Optional[List[CreateExtensionResponseServiceFeaturesItem]] = None
    """
    Extension service features returned in response only when the logged-in user requests his/her
    own extension info, see also Extension Service Features
    """
    
    setup_wizard_state: Optional[CreateExtensionResponseSetupWizardState] = None
    """
    Specifies extension configuration wizard state (web service setup). The default value is
    'NotStarted'
    """
    
    site: Optional[CreateExtensionResponseSite] = None
    """
    Site data. If multi-site feature is turned on for the account, then internal identifier of a
    site must be specified. To assign the wireless point to the main site (company) set site ID to
    `main-site`
    """
    
    status: Optional[CreateExtensionResponseStatus] = None
    """
    Extension current state. If 'Unassigned' is specified, then extensions without
    ‘extensionNumber’ are returned. If not specified, then all extensions are returned
    """
    
    status_info: Optional[CreateExtensionResponseStatusInfo] = None
    """ Status information (reason, comment). Returned for 'Disabled' status only """
    
    type: Optional[CreateExtensionResponseType] = None
    """ Extension type """
    
    hidden: Optional[bool] = None
    """ Hides extension from showing in company directory. Supported for extensions of User type only """
    

class ListUserTemplatesType(Enum):
    UserSettings = 'UserSettings'
    CallHandling = 'CallHandling'

class ListUserTemplatesResponseRecordsItemType(Enum):
    UserSettings = 'UserSettings'
    CallHandling = 'CallHandling'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListUserTemplatesResponseRecordsItem(DataClassJsonMixin):
    uri: Optional[str] = None
    """ Link to a template """
    
    id: Optional[str] = None
    """ Internal identifier of a template """
    
    type: Optional[ListUserTemplatesResponseRecordsItemType] = None
    name: Optional[str] = None
    """ Name of a template """
    
    creation_time: Optional[str] = None
    """ Time of a template creation """
    
    last_modified_time: Optional[str] = None
    """ Time of the last template modification """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListUserTemplatesResponseNavigationFirstPage(DataClassJsonMixin):
    """ Canonical URI for the first page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListUserTemplatesResponseNavigationNextPage(DataClassJsonMixin):
    """ Canonical URI for the next page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListUserTemplatesResponseNavigationPreviousPage(DataClassJsonMixin):
    """ Canonical URI for the previous page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListUserTemplatesResponseNavigationLastPage(DataClassJsonMixin):
    """ Canonical URI for the last page of the list """
    
    uri: Optional[str] = None

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListUserTemplatesResponseNavigation(DataClassJsonMixin):
    """ Information on navigation """
    
    first_page: Optional[ListUserTemplatesResponseNavigationFirstPage] = None
    """ Canonical URI for the first page of the list """
    
    next_page: Optional[ListUserTemplatesResponseNavigationNextPage] = None
    """ Canonical URI for the next page of the list """
    
    previous_page: Optional[ListUserTemplatesResponseNavigationPreviousPage] = None
    """ Canonical URI for the previous page of the list """
    
    last_page: Optional[ListUserTemplatesResponseNavigationLastPage] = None
    """ Canonical URI for the last page of the list """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListUserTemplatesResponsePaging(DataClassJsonMixin):
    """ Information on paging """
    
    page: Optional[int] = None
    """
    The current page number. 1-indexed, so the first page is 1 by default. May be omitted if result
    is empty (because non-existent page was specified or perPage=0 was requested)
    """
    
    per_page: Optional[int] = None
    """
    Current page size, describes how many items are in each page. Default value is 100. Maximum
    value is 1000. If perPage value in the request is greater than 1000, the maximum value (1000)
    is applied
    """
    
    page_start: Optional[int] = None
    """
    The zero-based number of the first element on the current page. Omitted if the page is omitted
    or result is empty
    """
    
    page_end: Optional[int] = None
    """
    The zero-based index of the last element on the current page. Omitted if the page is omitted or
    result is empty
    """
    
    total_pages: Optional[int] = None
    """
    The total number of pages in a dataset. May be omitted for some resources due to performance
    reasons
    """
    
    total_elements: Optional[int] = None
    """
    The total number of elements in a dataset. May be omitted for some resource due to performance
    reasons
    """
    

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ListUserTemplatesResponse(DataClassJsonMixin):
    """
    Required Properties:
     - navigation
     - paging
     - records
    
    Generated by Python OpenAPI Parser
    """
    
    records: List[ListUserTemplatesResponseRecordsItem]
    """ List of user templates """
    
    navigation: ListUserTemplatesResponseNavigation
    """ Information on navigation """
    
    paging: ListUserTemplatesResponsePaging
    """ Information on paging """
    
    uri: Optional[str] = None
    """ Link to user templates resource """
    

class ReadUserTemplateResponseType(Enum):
    UserSettings = 'UserSettings'
    CallHandling = 'CallHandling'

@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ReadUserTemplateResponse(DataClassJsonMixin):
    uri: Optional[str] = None
    """ Link to a template """
    
    id: Optional[str] = None
    """ Internal identifier of a template """
    
    type: Optional[ReadUserTemplateResponseType] = None
    name: Optional[str] = None
    """ Name of a template """
    
    creation_time: Optional[str] = None
    """ Time of a template creation """
    
    last_modified_time: Optional[str] = None
    """ Time of the last template modification """
    

class ReadUserVideoConfigurationResponseProvider(Enum):
    """ Video provider of the user """
    
    RCMeetings = 'RCMeetings'
    RCVideo = 'RCVideo'
    None_ = 'None'
